@@ -594,8 +594,6 @@ static int __init snd_cmi8330_probe(int dev, struct snd_cmi8330 *acard)
 	return -ENXIO;
 }
 
-#ifdef MODULE
-
 static void __exit snd_cmi8330_free(int dev)
 {
 	struct snd_cmi8330 *acard;
@@ -613,7 +611,7 @@ static void __exit snd_cmi8330_free(int dev)
 	}
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_card_cmi8330_exit(void)
 {
 	int i;
 
@@ -622,13 +620,7 @@ void __exit cleanup_module(void)
 	}
 }
 
-#endif
-
-#ifdef MODULE
-int __init init_module(void)
-#else
-int __init alsa_card_cmi8330_init(void)
-#endif
+static int __init alsa_card_cmi8330_init(void)
 {
 	int dev, cards;
 	struct snd_cmi8330 *acard;
@@ -664,3 +656,6 @@ int __init alsa_card_cmi8330_init(void)
 	}
 	return 0;
 }
+
+module_init(alsa_card_cmi8330_init)
+module_exit(alsa_card_cmi8330_exit)
