@@ -318,7 +318,7 @@ static int snd_card_dummy_playback_open(void *private_data,
 	}
 	dpcm->timer.data = (unsigned long) dpcm;
 	dpcm->timer.function = snd_card_dummy_pcm_interrupt;
-	dpcm->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&dpcm->lock);
 	dpcm->subchn = subchn;
 	subchn->runtime->private_data = dpcm;
 	subchn->runtime->private_free = _snd_magic_kfree;
@@ -342,7 +342,7 @@ static int snd_card_dummy_capture_open(void *private_data,
 	}
 	dpcm->timer.data = (unsigned long) dpcm;
 	dpcm->timer.function = snd_card_dummy_pcm_interrupt;
-	dpcm->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&dpcm->lock);
 	dpcm->subchn = subchn;
 	subchn->runtime->private_data = dpcm;
 	subchn->runtime->private_free = _snd_magic_kfree;
@@ -562,7 +562,7 @@ int __init snd_card_dummy_new_mixer(snd_card_dummy_t * dummy, int device)
 	};
 
 	snd_debug_check(dummy == NULL, -EINVAL);
-	dummy->mixer_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&dummy->mixer_lock);
 	if ((err = snd_mixer_new(dummy->card, "Dummy mixer", device, &mixer)) < 0)
 		return err;
 	strcpy(mixer->name, mixer->id);
@@ -784,11 +784,7 @@ static int __init snd_card_dummy_probe(int dev, struct snd_card_dummy *dummy)
 	return -ENXIO;
 }
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-int __init alsa_card_share_init(void)
-#endif
+int __init alsa_card_dummy_init(void)
 {
 	int dev, cards;
 	snd_card_dummy_t *dummy;
@@ -815,9 +811,7 @@ int __init alsa_card_share_init(void)
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_card_dummy_exit(void)
 {
 	int idx;
 
@@ -826,4 +820,5 @@ void __exit cleanup_module(void)
 	}
 }
 
-#endif
+module_init(alsa_card_dummy_init)
+module_exit(alsa_card_dummy_exit)
