@@ -226,7 +226,7 @@ static int __init snd_interwave_detect_stb(struct snd_interwave *iwcard,
 	if (bus == NULL)
 		goto __nodev;
 	bus->data = (void *) ((unsigned long) port);
-	bus->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&bus->lock);
 	bus->i2c_setlines = snd_interwave_i2c_setlines;
 	bus->i2c_getdataline = snd_interwave_i2c_getdataline;
 	SND_LOCK_I2C_BUS(bus);
@@ -1039,15 +1039,7 @@ static int __exit snd_interwave_free(int dev)
 
 #endif
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-#ifndef SND_STB
-int __init alsa_card_interwave_init(void)
-#else
-int __init alsa_card_interwave_stb_init(void)
-#endif
-#endif
+static int __init alsa_card_interwave_init(void)
 {
 	int dev, cards;
 	struct snd_interwave *iwcard;
@@ -1080,9 +1072,7 @@ int __init alsa_card_interwave_stb_init(void)
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_card_interwave_exit(void)
 {
 	int dev;
 
@@ -1090,4 +1080,5 @@ void __exit cleanup_module(void)
 		snd_interwave_free(dev);
 }
 
-#endif
+module_init(alsa_card_interwave_init)
+module_exit(alsa_card_interwave_exit)
