@@ -617,17 +617,7 @@ static void snd_card_opti9xx_free(struct snd_card_opti9xx *acard)
 	snd_kfree(acard);
 }
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-#ifdef OPTi93X
-int __init alsa_card_opti93x_init(void)
-#elif defined(CS4231)
-int __init alsa_card_opti92x_cs4231_init(void)
-#else
-int __init alsa_card_opti92x_ad1848_init(void)
-#endif
-#endif
+static int __init alsa_card_opti9xx_init(void)
 {
 	int error;
 	struct snd_card_opti9xx *acard;
@@ -654,12 +644,10 @@ int __init alsa_card_opti92x_ad1848_init(void)
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_card_opti9xx_exit(void)
 {
 	snd_card_opti9xx_free(snd_card_opti9xx_card);
 }
 
-#endif
-
+module_init(alsa_card_opti9xx_init)
+module_exit(alsa_card_opti9xx_exit)
