@@ -499,7 +499,7 @@ static int __init snd_sb16_isapnp(int dev, struct snd_sb16 *acard)
 	snd_dma8[dev] = pdev->dma_resource[0].start;
 	snd_dma16[dev] = pdev->dma_resource[1].start;
 	snd_irq[dev] = pdev->irq_resource[0].start;
-	snd_printdd("isapnp SB16: port=0x%lx, mpu port=0x%lx, fm port=0x%lx\n",
+	snd_printdd("isapnp SB16: port=0x%x, mpu port=0x%x, fm port=0x%x\n",
 			snd_port[dev], snd_mpu_port[dev], snd_fm_port[dev]);
 	snd_printdd("isapnp SB16: dma1=%i, dma2=%i, irq=%i\n",
 			snd_dma8[dev], snd_dma16[dev], snd_irq[dev]);
@@ -567,13 +567,16 @@ static int __init snd_sb16_probe(int dev, struct snd_sb16 *acard)
 		return -ENOMEM;
 	card->static_data = acard;
 	card->type = SND_CARD_TYPE_SB_16;	/* overriden in probe function */
-#ifndef __ISAPNP__
-	if (snd_sb16_resources(dev, acard, card) < 0) {
+#ifdef __ISAPNP__
+	if (snd_isapnp[dev] && snd_sb16_isapnp(dev, acard) < 0) {
 		snd_card_free(card);
 		return -EBUSY;
 	}
 #endif
-	pcm = NULL;
+	if (snd_sb16_resources(dev, acard, card) < 0) {
+		snd_card_free(card);
+		return -EBUSY;
+	}
 #ifndef __ISAPNP__
 	if (snd_port[dev] == SND_AUTO_PORT) {
 		for (ports = possible_ports; *ports >= 0; ports++) {
@@ -585,15 +588,6 @@ static int __init snd_sb16_probe(int dev, struct snd_sb16 *acard)
 				break;
 		}
 	} else {
-#else
-		if (snd_isapnp[dev] && snd_sb16_isapnp(dev, acard) < 0) {
-			snd_card_free(card);
-			return -EBUSY;
-		}
-		if (snd_sb16_resources(dev, acard, card) < 0) {
-			snd_card_free(card);
-			return -EBUSY;
-		}
 #endif
 		pcm = snd_sb16_detect(dev, card, snd_port[dev],
 				      acard->irqptr,
@@ -725,15 +719,7 @@ static int __exit snd_sb16_free(int dev)
 
 #endif
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-#ifdef SND_SBAWE_EMU8000
-int __init alsa_card_sbawe_init(void)
-#else
-int __init alsa_card_sb16_init(void)
-#endif
-#endif
+static int __init alsa_card_sb16_init(void)
 {
 	int dev, cards;
 	struct snd_sb16 *acard;
@@ -766,9 +752,7 @@ int __init alsa_card_sb16_init(void)
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_card_sb16_exit(void)
 {
 	int dev;
 
@@ -776,4 +760,5 @@ void __exit cleanup_module(void)
 		snd_sb16_free(dev);
 }
 
-#endif
+module_init(alsa_card_sb16_init)
+module_exit(alsa_card_sb16_exit)
