@@ -640,7 +640,7 @@ static int snd_card_share_playback_open(void *private_data,
 	dpcm->next = pcmo->pcm_list;
 	pcmo->pcm_list = dpcm;
 	up(&pcmo->open_mutex);
-	dpcm->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&dpcm->lock);
 	dpcm->subchn = subchn;
 	dpcm->pcmo = pcmo;
 	subchn->runtime->private_data = dpcm;
@@ -704,7 +704,7 @@ static int snd_card_share_capture_open(void *private_data,
 	dpcm->next = pcmo->pcm_list;
 	pcmo->pcm_list = dpcm;
 	up(&pcmo->open_mutex);
-	dpcm->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&dpcm->lock);
 	dpcm->subchn = subchn;
 	dpcm->pcmo = pcmo;
 	subchn->runtime->private_data = dpcm;
@@ -835,7 +835,7 @@ static int __init snd_card_share_pcm(snd_card_share_t *share, int device,
 			return -ENOMEM;
 		}
 		init_MUTEX(&pcmo->open_mutex);
-		pcmo->run_lock = SPIN_LOCK_UNLOCKED;
+		spin_lock_init(&pcmo->run_lock);
 		pcmo->share = share;
 		pcmo->pcm_card = pcm_card;
 		pcmo->pcm_dev = pcm_dev;
@@ -852,7 +852,7 @@ static int __init snd_card_share_pcm(snd_card_share_t *share, int device,
 			return -ENOMEM;
 		}
 		init_MUTEX(&pcmo->open_mutex);
-		pcmo->run_lock = SPIN_LOCK_UNLOCKED;
+		spin_lock_init(&pcmo->run_lock);
 		pcmo->share = share;
 		pcmo->pcm_card = pcm_card;
 		pcmo->pcm_dev = pcm_dev;
@@ -1301,11 +1301,7 @@ static int __init snd_card_share_probe(int dev, struct snd_card_share *share)
 	return -ENXIO;
 }
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-int __init alsa_card_share_init(void)
-#endif
+static int __init alsa_card_share_init(void)
 {
 	int dev, cards;
 	snd_card_share_t *share;
@@ -1333,9 +1329,7 @@ int __init alsa_card_share_init(void)
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_card_share_exit(void)
 {
 	int idx;
 
@@ -1344,4 +1338,5 @@ void __exit cleanup_module(void)
 	}
 }
 
-#endif
+module_init(alsa_card_share_init)
+module_exit(alsa_card_share_exit)
