@@ -891,11 +891,7 @@ snd_wavefront_probe (int dev, snd_wavefront_card_t *acard)
 }	
 
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-int __init alsa_card_wavefront_init(void)
-#endif
+static int __init alsa_card_wavefront_init(void)
 {
 	int dev, cards;
 	snd_wavefront_card_t *acard;
@@ -911,16 +907,9 @@ int __init alsa_card_wavefront_init(void)
 			continue;
 
 		init_waitqueue_head(&acard->wavefront.interrupt_sleeper);
-		
-                acard->wavefront.midi.open =  SPIN_LOCK_UNLOCKED;
-		acard->wavefront.midi.input =  SPIN_LOCK_UNLOCKED;
-		acard->wavefront.midi.output =  SPIN_LOCK_UNLOCKED;
-		acard->wavefront.midi.virtual =  SPIN_LOCK_UNLOCKED;
 
-		acard->wavefront.midi.open = SPIN_LOCK_UNLOCKED;
-		acard->wavefront.midi.input = SPIN_LOCK_UNLOCKED;
-		acard->wavefront.midi.output = SPIN_LOCK_UNLOCKED;
-		acard->wavefront.midi.virtual = SPIN_LOCK_UNLOCKED;
+		spin_lock_init(&acard->wavefront.midi.open);
+		spin_lock_init(&acard->wavefront.midi.virtual);
 
 		if (snd_wavefront_probe (dev, acard) < 0) {
 			snd_kfree (acard);
@@ -942,9 +931,7 @@ int __init alsa_card_wavefront_init(void)
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_card_wavefront_exit(void)
 {
 	int idx;
 	snd_wavefront_card_t *acard;
@@ -958,4 +945,5 @@ void __exit cleanup_module(void)
 	}
 }
 
-#endif
+module_init(alsa_card_wavefront_init)
+module_exit(alsa_card_wavefront_exit)
