@@ -63,7 +63,7 @@ static int snd_mixer_open(unsigned short minor, int cardnum, int device,
 	if (mfile == NULL)
 		return -ENOMEM;
 	init_waitqueue_head(&mfile->change_sleep);
-	mfile->read_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&mfile->read_lock);
 	mfile->mixer = mixer;
 	memset(&mfile->read_filter, 0xff, sizeof(mfile->read_filter));
 	file->private_data = mfile;
@@ -1225,7 +1225,7 @@ int snd_mixer_new(snd_card_t * card, char *id, int device, snd_kmixer_t ** rmixe
 	if (id) {
 		strncpy(mixer->id, id, sizeof(mixer->id) - 1);
 	}
-	mixer->ffile_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&mixer->ffile_lock);
 	init_MUTEX(&mixer->lock);
 	snd_switch_prepare(card, &mixer->switches, mixer, SND_CTL_IFACE_MIXER, mixer->device, 0);
 	if ((err = snd_device_new(card, SND_DEV_MIXER, mixer, device, &ops, NULL)) < 0) {
@@ -1481,21 +1481,16 @@ EXPORT_SYMBOL(snd_mixer_lib_3d_effect1);
  *  INIT PART
  */
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-int __init alsa_mixer_init(void)
-#endif
+static int __init alsa_mixer_init(void)
 {
 	snd_control_register_ioctl(snd_mixer_control_ioctl);
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_mixer_exit(void)
 {
 	snd_control_unregister_ioctl(snd_mixer_control_ioctl);
 }
 
-#endif
+module_init(alsa_mixer_init)
+module_exit(alsa_mixer_exit)
