@@ -313,9 +313,9 @@ int snd_pcm_open_subchn(snd_pcm_t *pcm, int channel,
 	runtime->frag_head = &runtime->_sfrag_head;
 	runtime->frag_tail = &runtime->_sfrag_tail;
 	init_waitqueue_head(&runtime->sleep);
-	runtime->lock = SPIN_LOCK_UNLOCKED;
-	runtime->sleep_lock = SPIN_LOCK_UNLOCKED;
-	runtime->timer_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&runtime->lock);
+	spin_lock_init(&runtime->sleep_lock);
+	spin_lock_init(&runtime->timer_lock);
 
 	runtime->mode = SND_PCM_MODE_BLOCK;
 	*runtime->status = SND_PCM_STATUS_NOTREADY;
@@ -567,11 +567,7 @@ static void snd_pcm_proc_read(snd_info_buffer_t * buffer, void *private_data)
 
 static snd_info_entry_t *snd_pcm_proc_entry = NULL;
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-int __init alsa_pcm_init(void)
-#endif
+static int __init alsa_pcm_init(void)
 {
 	snd_info_entry_t *entry;
 
@@ -588,9 +584,7 @@ int __init alsa_pcm_init(void)
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_pcm_exit(void)
 {
 	snd_control_unregister_ioctl(snd_pcm_control_ioctl);
 	if (snd_pcm_proc_entry) {
@@ -599,7 +593,8 @@ void __exit cleanup_module(void)
 	}
 }
 
-#endif
+module_init(alsa_pcm_init)
+module_exit(alsa_pcm_exit)
 
 EXPORT_SYMBOL(snd_pcm_lock);
 EXPORT_SYMBOL(snd_pcm_devices);
