@@ -182,6 +182,17 @@ static inline unsigned int snd_pcm_lib_get_stream_ptr(snd_pcm_subchn_t *subchn,
 	return runtime->last_position = ptr;
 }
 
+static inline unsigned int snd_pcm_lib_get_block_ptr(snd_pcm_subchn_t *subchn, snd_pcm_runtime_t *runtime)
+{
+	unsigned int ptr;
+
+	ptr = subchn->runtime->hw->pointer(subchn->pchn->private_data, subchn);
+	ptr += runtime->buf_position;
+	while (ptr < runtime->last_position)
+		ptr += runtime->buf.block.frag_size;
+	return runtime->last_position = ptr;
+}
+
 int snd_pcm_lib_fragment(long size, snd_pcm_hardware_t *hw)
 {
 	if (size < hw->min_fragment_size)
@@ -372,23 +383,23 @@ static int snd_pcm_lib_ioctl_status(void *private_data,
 
 	spin_lock_irqsave(&runtime->lock, flags);
 	if (runtime->flags & SND_PCM_FLG_TIME) {
-		status->stime = runtime->stime;
+		memcpy(&status->stime, &runtime->stime, sizeof(struct timeval));
 	} else {
 		status->stime.tv_sec = status->stime.tv_usec = 0;
 	}
 	status->ust_stime = 0;	/* TODO */
 	if (runtime->mode == SND_PCM_MODE_BLOCK) {
-		status->scount = runtime->buf_position;
 		if (subchn->channel == SND_PCM_CHANNEL_PLAYBACK) {
 			status->frag = *runtime->frag_tail;
 		} else {
 			status->frag = *runtime->frag_head;
 		}
-		ptr = runtime->hw->pointer(private_data, subchn);
+		ptr = snd_pcm_lib_get_block_ptr(subchn, runtime);
+		status->scount = runtime->buf_position;
+		status->scount += ptr % runtime->buf.block.frag_size;
 		if (!(runtime->flags & SND_PCM_FLG_OSS_MMAP)) {
-			if (runtime->flags & SND_PCM_FLG_OSS_MMAP) {
+			if (runtime->flags & SND_PCM_FLG_MMAP) {
 				status->count = status->free = 0;
-				status->scount += ptr % runtime->buf.block.frag_size;
 			} else {
 				status->count = runtime->frag_used * runtime->buf.block.frag_size;
 				status->free = (runtime->frags - runtime->frag_used) * runtime->buf.block.frag_size;
@@ -404,7 +415,6 @@ static int snd_pcm_lib_ioctl_status(void *private_data,
 			status->count = runtime->interrupts;
 			runtime->interrupts = 0;
 			status->free = 0;
-			status->scount += ptr % runtime->buf.block.frag_size;
 		}
 	} else if (runtime->mode == SND_PCM_MODE_STREAM) {
 		ptr = snd_pcm_lib_get_stream_ptr(subchn, runtime);
@@ -780,8 +790,9 @@ static void snd_pcm_lib_boundary_playback(snd_pcm_runtime_t *runtime)
 	unsigned int used;
 
 	if (runtime->mode == SND_PCM_MODE_BLOCK) {
-		used = runtime->buf.block.frag_size * runtime->frags;
+		used = (runtime->buf.block.frag_size * runtime->frags) * 4;
 		runtime->buf_position %= used;
+		runtime->last_position %= used;
 	} else if (runtime->mode == SND_PCM_MODE_STREAM) {
 #ifdef CONFIG_SND_DEBUG
 		if (runtime->position < runtime->buf_position)
@@ -805,16 +816,18 @@ static void snd_pcm_lib_boundary_capture(snd_pcm_runtime_t *runtime)
 	unsigned int used;
 
 	if (runtime->mode == SND_PCM_MODE_BLOCK) {
-		used = runtime->buf.block.frag_size * runtime->frags;
+		used = (runtime->buf.block.frag_size * runtime->frags) * 4;
 		runtime->buf_position %= used;
+		runtime->last_position %= used;
 	} else if (runtime->mode == SND_PCM_MODE_STREAM) {
 #ifdef CONFIG_SND_DEBUG
 		if (runtime->position > runtime->buf_position)
 			snd_printk("snd_pcm_boundary_playback: position = %u, buf_position = %u\n", runtime->position, runtime->buf_position);
 #endif
-		used = runtime->buf.stream.queue_size;
+		used = runtime->buf.stream.queue_size * 8;
 		runtime->buf_position %= used;
 		runtime->position %= used;
+		runtime->last_position %= used;
 		if (runtime->position > runtime->buf_position)
 			runtime->buf_position += used;
 	}
