@@ -87,9 +87,9 @@ int snd_pcm_channel_info(snd_pcm_subchn_t * subchn, snd_pcm_channel_info_t * _in
 	info.fifo_size = hw->fifo_size;
 	info.transfer_block_size = hw->transfer_block_size;
 	if (runtime->dig_mask)
-		info.dig_mask = *runtime->dig_mask;
+		memcpy(&info.dig_mask, runtime->dig_mask, sizeof(snd_pcm_digital_t));
 	info.mixer_device = runtime->mixer_device;
-	info.mixer_eid = runtime->mixer_eid;
+	memcpy(&info.mixer_eid, &runtime->mixer_eid, sizeof(snd_mixer_eid_t));
 	runtime->hw->ioctl(subchn->pchn->private_data, subchn,
 			   SND_PCM_IOCTL1_INFO, (unsigned long *)&info);
 	runtime->hw->ioctl(subchn->pchn->private_data, subchn,
@@ -133,16 +133,16 @@ static int snd_pcm_channel_params(snd_pcm_subchn_t * subchn, snd_pcm_channel_par
 	runtime->flags &= ~SND_PCM_FLG_TIME;
 	if (params.time)
 		runtime->flags |= SND_PCM_FLG_TIME;
-	runtime->format = params.format;
+	memcpy(&runtime->format, &params.format, sizeof(snd_pcm_format_t));
 	if (!params.format.interleave && runtime->mode == SND_PCM_MODE_STREAM)
 		return -EINVAL;
-	runtime->digital = params.digital;
+ 	memcpy(&runtime->digital, &params.digital, sizeof(snd_pcm_digital_t)); 
 	if (params.time) {
 		runtime->flags |= SND_PCM_FLG_TIMESTAMP;
 	} else {
 		runtime->flags &= ~SND_PCM_FLG_TIMESTAMP;
 	}
-	runtime->sync_group = params.sync;
+	memcpy(&runtime->sync_group, &params.sync, sizeof(snd_pcm_sync_t));
 	if (runtime->mode == SND_PCM_MODE_STREAM) {
 		runtime->buf.stream.queue_size = params.buf.stream.queue_size;
 		runtime->buf.stream.fill = params.buf.stream.fill;
@@ -176,7 +176,7 @@ static int snd_pcm_channel_setup(snd_pcm_subchn_t * subchn, snd_pcm_channel_setu
 	setup.channel = subchn->channel;
 	setup.mode = runtime->mode;
 	setup.format = runtime->format;
-	setup.digital = runtime->digital;
+	memcpy(&setup.digital, &runtime->digital, sizeof(snd_pcm_digital_t)); 
 	if (runtime->mode == SND_PCM_MODE_STREAM) {
 		setup.buf.stream.queue_size = runtime->buf.stream.queue_size;
 	} else {
@@ -879,7 +879,7 @@ static int snd_pcm_mmap(struct inode *inode, struct file *file,
 	if (*runtime->status != SND_PCM_STATUS_READY)
 		return -EBADFD;
 	size = area->vm_end - area->vm_start;
-#if LinuxVersionCode(2, 3, 25) <= LINUX_VERSION_CODE
+#if KERNEL_VERSION(2, 3, 25) <= LINUX_VERSION_CODE
 	switch (area->vm_pgoff << PAGE_SHIFT) {
 #else
 	switch (area->vm_offset) {
