@@ -1093,7 +1093,8 @@ static int snd_pcm_oss_get_odelay(snd_pcm_oss_file_t *pcm_oss_file)
 	int err;
 
 	subchn = pcm_oss_file->chn[SND_PCM_CHANNEL_PLAYBACK];
-	snd_debug_check(subchn == NULL, -EINVAL);
+	if (subchn == NULL)
+		return -EINVAL;
 	if ((err = snd_pcm_oss_make_ready(subchn)) < 0)
 		return err;
 	runtime = subchn->runtime;
@@ -1117,7 +1118,8 @@ static int snd_pcm_oss_get_ptr(snd_pcm_oss_file_t *pcm_oss_file, int channel, st
 	if (_info == NULL)
 		return -EFAULT;
 	subchn = pcm_oss_file->chn[channel];
-	snd_debug_check(subchn == NULL, -EINVAL);
+	if (subchn == NULL)
+		return -EINVAL;
 	if ((err = snd_pcm_oss_make_ready(subchn)) < 0)
 		return err;
 	runtime = subchn->runtime;
@@ -1156,7 +1158,8 @@ static int snd_pcm_oss_get_space(snd_pcm_oss_file_t *pcm_oss_file, int channel,
 	if (_info == NULL)
 		return -EFAULT;
 	subchn = pcm_oss_file->chn[channel];
-	snd_debug_check(subchn == NULL, -EINVAL);
+	if (subchn == NULL)
+		return -EINVAL;
 	runtime = subchn->runtime;
 
 	if (runtime->oss.params &&
@@ -1748,7 +1751,7 @@ static int snd_pcm_oss_mmap(struct inode *inode, struct file *file,
 	pdma = runtime->dma_area;
 	if (pdma == NULL)
 		return -ENOENT;
-#if LinuxVersionCode(2, 3, 25) <= LINUX_VERSION_CODE
+#if KERNEL_VERSION(2, 3, 25) <= LINUX_VERSION_CODE
 	if (area->vm_pgoff != 0)
 #else
 	if (area->vm_offset != 0)
@@ -2011,11 +2014,7 @@ static struct snd_stru_pcm_notify snd_pcm_oss_notify =
 	NULL
 };
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-int __init alsa_pcm_oss_init(void)
-#endif
+static int __init alsa_pcm_oss_init(void)
 {
 	int err;
 
@@ -2024,11 +2023,10 @@ int __init alsa_pcm_oss_init(void)
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_pcm_oss_exit(void)
 {
 	snd_pcm_notify(&snd_pcm_oss_notify, 1);
 }
 
-#endif
+module_init(alsa_pcm_oss_init)
+module_exit(alsa_pcm_oss_exit)
