@@ -102,141 +102,12 @@ int snd_rawmidi_done_buffer(snd_rawmidi_t * rmidi, int channel)
 	return 0;
 }
 
-static void snd_rawmidi_poll_output(unsigned long data)
-{
-	unsigned long flags;
-	snd_rawmidi_t *rmidi;
-	snd_rawmidi_channel_t *pchn;
-
-	rmidi = (snd_rawmidi_t *) data;
-	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
-	pchn->hw.io.write(rmidi);
-	spin_lock_irqsave(&pchn->lock, flags);
-	if (pchn->used > 0) {
-		pchn->flags |= SND_RAWMIDI_FLG_TIMER;
-		pchn->timer.expires = 1 + jiffies;
-		add_timer(&pchn->timer);
-	} else {
-		del_timer(&pchn->timer);
-		pchn->flags &= ~SND_RAWMIDI_FLG_TIMER;
-	}
-	spin_unlock_irqrestore(&pchn->lock, flags);
-}
-
-static void snd_rawmidi_trigger_output(snd_rawmidi_t * rmidi, int up)
-{
-	unsigned long flags;
-	int flg;
-	snd_rawmidi_channel_t *pchn;
-
-	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
-#if 0
-	snd_printk("trigger_output - %i\n", up);
-#endif
-	if (!(pchn->hw.flags & SND_RAWMIDI_HW_POLL)) {
-		flg = up ? SND_RAWMIDI_FLG_TRIGGER : 0;
-		spin_lock_irqsave(&pchn->lock, flags);
-		if ((pchn->flags & SND_RAWMIDI_FLG_TRIGGER) != flg) {
-			if (up) {
-				pchn->flags |= SND_RAWMIDI_FLG_TRIGGER;
-			} else {
-				pchn->flags &= ~SND_RAWMIDI_FLG_TRIGGER;
-			}
-			spin_unlock_irqrestore(&pchn->lock, flags);
-			pchn->hw.trigger(rmidi, up);
-			return;
-		}
-		spin_unlock_irqrestore(&pchn->lock, flags);
-	} else {
-		spin_lock_irqsave(&pchn->lock, flags);
-		if (up) {
-			if (!(pchn->flags & SND_RAWMIDI_FLG_TIMER)) {
-				spin_unlock_irqrestore(&pchn->lock, flags);
-				pchn->hw.io.write(rmidi);
-				spin_lock_irqsave(&pchn->lock, flags);
-				if (pchn->used > 0) {
-					pchn->flags |= SND_RAWMIDI_FLG_TIMER;
-					pchn->timer.expires = 1 + jiffies;
-					add_timer(&pchn->timer);
-				}
-			}
-		} else {
-			if (pchn->flags & SND_RAWMIDI_FLG_TIMER) {
-				pchn->flags &= ~SND_RAWMIDI_FLG_TIMER;
-				del_timer(&pchn->timer);
-			}
-		}
-		spin_unlock_irqrestore(&pchn->lock, flags);
-	}
-}
-
-static void snd_rawmidi_poll_input(unsigned long data)
-{
-	unsigned long flags;
-	snd_rawmidi_t *rmidi;
-	snd_rawmidi_channel_t *pchn;
-
-	rmidi = (snd_rawmidi_t *) data;
-	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
-	pchn->hw.io.read(rmidi);
-	spin_lock_irqsave(&pchn->lock, flags);
-	pchn->flags |= SND_RAWMIDI_FLG_TIMER;
-	pchn->timer.data = (unsigned long) rmidi;
-	pchn->timer.expires = 1 + jiffies;
-	add_timer(&pchn->timer);
-	spin_unlock_irqrestore(&pchn->lock, flags);
-}
-
-static void snd_rawmidi_trigger_input(snd_rawmidi_t * rmidi, int up)
-{
-	unsigned long flags;
-	int flg;
-	snd_rawmidi_channel_t *pchn;
-	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
-
-#if 0
-	snd_printk("trigger_input - %i\n", up);
-#endif
-	if (!(pchn->hw.flags & SND_RAWMIDI_HW_POLL)) {
-		flg = up ? SND_RAWMIDI_FLG_TRIGGER : 0;
-		spin_lock_irqsave(&pchn->lock, flags);
-		if ((pchn->flags & SND_RAWMIDI_FLG_TRIGGER) != flg) {
-			if (up) {
-				pchn->flags |= SND_RAWMIDI_FLG_TRIGGER;
-			} else {
-				pchn->flags &= ~SND_RAWMIDI_FLG_TRIGGER;
-			}
-			spin_unlock_irqrestore(&pchn->lock, flags);
-			pchn->hw.trigger(rmidi, up);
-			return;
-		}
-		spin_unlock_irqrestore(&pchn->lock, flags);
-	} else {
-		spin_lock_irqsave(&pchn->lock, flags);
-		if (up) {
-			if (!(pchn->flags & SND_RAWMIDI_FLG_TIMER)) {
-				spin_unlock_irqrestore(&pchn->lock, flags);
-				pchn->hw.io.read(rmidi);
-				spin_lock_irqsave(&pchn->lock, flags);
-				pchn->flags |= SND_RAWMIDI_FLG_TIMER;
-				pchn->timer.expires = 1 + jiffies;
-				add_timer(&pchn->timer);
-			}
-		} else {
-			if (pchn->flags & SND_RAWMIDI_FLG_TIMER) {
-				pchn->flags &= ~SND_RAWMIDI_FLG_TIMER;
-				del_timer(&pchn->timer);
-			}
-		}
-		spin_unlock_irqrestore(&pchn->lock, flags);
-	}
-}
-
 int snd_rawmidi_drain_output(snd_rawmidi_t * rmidi)
 {
 	snd_rawmidi_channel_t *pchn;
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
-	snd_rawmidi_trigger_output(rmidi, 0);
+	pchn->hw.trigger(rmidi, 0);
+	pchn->flags = 0;
 	/* interrupts aren't enabled at this moment, so spinlock isn't needed */
 	pchn->used =
 	pchn->head =
@@ -249,13 +120,12 @@ int snd_rawmidi_flush_output(snd_rawmidi_t * rmidi)
 	int err;
 	long timeout;
 	snd_rawmidi_channel_t *pchn;
+	wait_queue_head_t wait;
 
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
 	err = 0;
+	pchn->flags |= SND_RAWMIDI_FLG_FLUSH;
 	while (pchn->used > 0) {
-#if 0
-		snd_printk("flush - used = %i\n", pchn->used);
-#endif
 		timeout = interruptible_sleep_on_timeout(&pchn->sleep, 10 * HZ);
 		if (signal_pending(current)) {
 			err = -EINTR;
@@ -266,6 +136,9 @@ int snd_rawmidi_flush_output(snd_rawmidi_t * rmidi)
 			break;
 		}
 	}
+	pchn->flags &= ~SND_RAWMIDI_FLG_FLUSH;
+	init_waitqueue_head(&wait);
+	interruptible_sleep_on_timeout(&wait, HZ / 20);
 	snd_rawmidi_drain_output(rmidi);
 	return err;
 }
@@ -274,7 +147,8 @@ int snd_rawmidi_flush_input(snd_rawmidi_t * rmidi)
 {
 	snd_rawmidi_channel_t *pchn;
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
-	snd_rawmidi_trigger_input(rmidi, 0);
+	pchn->hw.trigger(rmidi, 0);
+	pchn->flags = 0;
 	/* interrupts aren't enabled at this moment, so spinlock isn't needed */
 	pchn->used =
 	pchn->head =
@@ -395,14 +269,9 @@ static int snd_rawmidi_open(unsigned short minor, int cardnum, int device,
 int snd_rawmidi_kernel_release(snd_rawmidi_t *rmidi, int mode)
 {
 	snd_debug_check(rmidi == NULL, -ENXIO);
-	if (mode & SND_RAWMIDI_LFLG_OUTPUT) {
-		wait_queue_head_t wait;
-		init_waitqueue_head(&wait);
-		interruptible_sleep_on_timeout(&wait, HZ / 20);
-	}
 	down(&rmidi->open_mutex);
 	if (mode & SND_RAWMIDI_LFLG_INPUT) {
-		snd_rawmidi_trigger_input(rmidi, 0);
+		rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT].hw.trigger(rmidi, 0);
 		rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT].hw.close(rmidi);
 		snd_rawmidi_done_buffer(rmidi, SND_RAWMIDI_CHANNEL_INPUT);
 	}
@@ -521,9 +390,9 @@ static int snd_rawmidi_output_status(snd_rawmidi_t * rmidi,
 	snd_rawmidi_channel_t *pchn;
 
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
-	memset(&status, 0, sizeof(status));
-	spin_lock_irqsave(&pchn->lock, flags);
+	memset(status, 0, sizeof(status));
 	status->channel = SND_RAWMIDI_CHANNEL_OUTPUT;
+	spin_lock_irqsave(&pchn->lock, flags);
 	status->size = pchn->size;
 	status->count = pchn->size - pchn->used;
 	status->queue = pchn->used;
@@ -538,9 +407,9 @@ static int snd_rawmidi_input_status(snd_rawmidi_t * rmidi,
 	snd_rawmidi_channel_t *pchn;
 
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
-	memset(&status, 0, sizeof(status));
-	spin_lock_irqsave(&pchn->lock, flags);
+	memset(status, 0, sizeof(status));
 	status->channel = SND_RAWMIDI_CHANNEL_INPUT;
+	spin_lock_irqsave(&pchn->lock, flags);
 	status->size = pchn->size;
 	status->count = pchn->used;
 	status->free = pchn->size - pchn->used;
@@ -719,13 +588,10 @@ void snd_rawmidi_receive_reset(snd_rawmidi_t * rmidi)
 int snd_rawmidi_receive(snd_rawmidi_t * rmidi, char *buffer, int count)
 {
 	unsigned long flags;
-	int count1;
+	int result = 0, count1;
 	snd_rawmidi_channel_t *pchn;
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
 
-#if 0
-	snd_printk("rx: count = %i\n", count);
-#endif
 	if (pchn->buffer == NULL) {
 		snd_printd("snd_rawmidi_receive: input isn't active!!!\n");
 		return -EINVAL;
@@ -735,14 +601,14 @@ int snd_rawmidi_receive(snd_rawmidi_t * rmidi, char *buffer, int count)
 	count1 = pchn->size - pchn->head;
 	if (count1 > count)
 		count1 = count;
-	if (count1 > pchn->size - pchn->used) {
+	if (count1 > pchn->size - pchn->used)
 		count1 = pchn->size - pchn->used;
-	}
 	memcpy(pchn->buffer + pchn->head, buffer, count1);
 	pchn->head += count1;
 	pchn->head %= pchn->size;
 	pchn->used += count1;
 	count -= count1;
+	result += count1;
 	if (count > 0) {
 		count1 = count;
 		if (count > pchn->size - pchn->used) {
@@ -753,19 +619,19 @@ int snd_rawmidi_receive(snd_rawmidi_t * rmidi, char *buffer, int count)
 			memcpy(pchn->buffer, buffer + count1, count1);
 			pchn->head = count1;
 			pchn->used += count1;
+			result += count1;
 		}
 	}
 	spin_unlock_irqrestore(&pchn->lock, flags);
-	if (pchn->event) {
-		pchn->event(rmidi);
-	} else {
-		if (snd_rawmidi_input_ok(rmidi))
-			wake_up(&pchn->sleep);
+	if (result > 0) {
+		if (pchn->event) {
+			pchn->event(rmidi);
+		} else {
+			if (snd_rawmidi_input_ok(rmidi))
+				wake_up(&pchn->sleep);
+		}
 	}
-#if 0
-	snd_printk("rx: head = %i, tail = %i, used = %i, size = %i\n", pchn->head, pchn->tail, pchn->used, pchn->size);
-#endif
-	return 0;
+	return result;
 }
 
 static long snd_rawmidi_kernel_read1(snd_rawmidi_t *rmidi, char *buf, long count, int kernel)
@@ -773,8 +639,8 @@ static long snd_rawmidi_kernel_read1(snd_rawmidi_t *rmidi, char *buf, long count
 	unsigned long flags;
 	long result = 0, count1;
 	snd_rawmidi_channel_t *pchn;
-	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
 
+	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
 	while (count > 0 && pchn->used) {
 		count1 = pchn->size - pchn->tail;
 		if (count1 > count)
@@ -787,7 +653,7 @@ static long snd_rawmidi_kernel_read1(snd_rawmidi_t *rmidi, char *buf, long count
 		} else {
 			if (copy_to_user(buf, pchn->buffer + pchn->tail, count1)) {
 				spin_unlock_irqrestore(&pchn->lock, flags);
-				return -EFAULT;
+				return result > 0 ? result : -EFAULT;
 			}
 		}
 		pchn->tail += count1;
@@ -802,7 +668,11 @@ static long snd_rawmidi_kernel_read1(snd_rawmidi_t *rmidi, char *buf, long count
 
 long snd_rawmidi_kernel_read(snd_rawmidi_t *rmidi, char *buf, long count)
 {
-	snd_rawmidi_trigger_input(rmidi, 1);
+	snd_rawmidi_channel_t *pchn;
+	
+	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
+	pchn->flags |= SND_RAWMIDI_FLG_TRIGGER;
+	pchn->hw.trigger(rmidi, 1);
 	return snd_rawmidi_kernel_read1(rmidi, buf, count, 1);
 }
 
@@ -815,8 +685,9 @@ static long snd_rawmidi_read(struct file *file, char *buf, long count)
 
 	rmidi = snd_magic_cast(snd_rawmidi_t, file->private_data, -ENXIO);
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
+	pchn->flags |= SND_RAWMIDI_FLG_TRIGGER;
+	pchn->hw.trigger(rmidi, 1);
 	result = 0;
-	snd_rawmidi_trigger_input(rmidi, 1);
 	while (count > 0) {
 		while (!snd_rawmidi_input_ok(rmidi)) {
 			if (file->f_flags & O_NONBLOCK)
@@ -840,21 +711,37 @@ void snd_rawmidi_transmit_reset(snd_rawmidi_t * rmidi)
 	/* TODO: reset current state */
 }
 
+int snd_rawmidi_transmit_empty(snd_rawmidi_t * rmidi)
+{
+	snd_rawmidi_channel_t *pchn;
+	int result;
+	unsigned long flags;
+
+	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
+	if (pchn->buffer == NULL) {
+		snd_printd("snd_rawmidi_transmit_empty: output isn't active!!!\n");
+		return 1;
+	}
+	spin_lock_irqsave(&pchn->lock, flags);
+	result = pchn->used > 0;
+	if (result)
+		pchn->flags &= ~SND_RAWMIDI_FLG_TRIGGER;
+	spin_unlock_irqrestore(&pchn->lock, flags);
+	return result;		
+}
+
 int snd_rawmidi_transmit(snd_rawmidi_t * rmidi, char *buffer, int count)
 {
 	unsigned long flags;
 	int result, count1;
 	snd_rawmidi_channel_t *pchn;
 
-	result = 0;
-#if 0
-	snd_printk("transmit: count = %i\n", count);
-#endif
 	pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
 	if (pchn->buffer == NULL) {
 		snd_printd("snd_rawmidi_transmit: output isn't active!!!\n");
 		return 0;
 	}
+	result = 0;
 	spin_lock_irqsave(&pchn->lock, flags);
 	count1 = pchn->size - pchn->tail;
 	if (count1 > count)
@@ -862,10 +749,9 @@ int snd_rawmidi_transmit(snd_rawmidi_t * rmidi, char *buffer, int count)
 	if (count1 > pchn->used)
 		count1 = pchn->used;
 	if (!count1) {
-		spin_unlock_irqrestore(&pchn->lock, flags);
-		snd_rawmidi_trigger_output(rmidi, 0);
-		wake_up(&pchn->sleep);
-		return 0;
+		/* warning: lowlevel layer MUST trigger down the hardware */
+		pchn->flags &= ~SND_RAWMIDI_FLG_TRIGGER;
+		goto __skip;
 	}
 	memcpy(buffer, pchn->buffer + pchn->tail, count1);
 	pchn->tail += count1;
@@ -879,24 +765,20 @@ int snd_rawmidi_transmit(snd_rawmidi_t * rmidi, char *buffer, int count)
 		pchn->used -= count;
 		result += count;
 	}
-	if (!pchn->used) {
-		spin_unlock_irqrestore(&pchn->lock, flags);
-		if (!result)
-			snd_rawmidi_trigger_output(rmidi, 0);
+	pchn->bytes += result;
+      __skip:
+	spin_unlock_irqrestore(&pchn->lock, flags);
+	if (result > 0) {
+		if (pchn->event) {
+			pchn->event(rmidi);
+		} else {
+			if (snd_rawmidi_output_ok(rmidi))
+				wake_up(&pchn->sleep);
+		}
 	} else {
-		spin_unlock_irqrestore(&pchn->lock, flags);
-	}
-	if (pchn->event) {
-		pchn->event(rmidi);
-	} else {
-		if (snd_rawmidi_output_ok(rmidi))
+		if (pchn->flags & SND_RAWMIDI_FLG_FLUSH)
 			wake_up(&pchn->sleep);
 	}
-#if 0
-	snd_printk("write1: head = %i, tail = %i, used = %i, size = %i\n", pchn->head, pchn->tail, pchn->used, pchn->size);
-	snd_printk("transmit result = %i\n", result);
-#endif
-	pchn->bytes += result;
 	return result;
 }
 
@@ -925,8 +807,8 @@ static long snd_rawmidi_kernel_write1(snd_rawmidi_t * rmidi, const char *buf, lo
 			memcpy(pchn->buffer + pchn->head, buf, count1);
 		} else {
 			if (copy_from_user(pchn->buffer + pchn->head, buf, count1)) {
-				spin_unlock_irqrestore(&pchn->lock, flags);
-				return -EFAULT;
+				result = result > 0 ? result : -EFAULT;
+				goto __end;
 			}
 		}
 		pchn->head += count1;
@@ -936,8 +818,11 @@ static long snd_rawmidi_kernel_write1(snd_rawmidi_t * rmidi, const char *buf, lo
 		buf += count1;
 		count -= count1;
 	}
+      __end:
+	if (result > 0)
+		pchn->flags |= SND_RAWMIDI_FLG_TRIGGER;
 	spin_unlock_irqrestore(&pchn->lock, flags);
-	snd_rawmidi_trigger_output(rmidi, 1);
+	pchn->hw.trigger(rmidi, 1);
 	return result;
 }
 
@@ -963,14 +848,15 @@ static long snd_rawmidi_write(struct file *file, const char *buf, long count)
 			timeout = interruptible_sleep_on_timeout(&pchn->sleep, 30 * HZ);
 			if (signal_pending(current))
 				return -EINTR;
-			if (pchn->used >= pchn->size &&
-			    !timeout)
+			if (pchn->used >= pchn->size && !timeout)
 				return -EIO;
 		}
 		count1 = snd_rawmidi_kernel_write1(rmidi, buf, count, 0);
 		result += count1;
 		buf += count1;
 		count -= count1;
+		if (count1 < count && (file->f_flags & O_NONBLOCK))
+			break;
 	}
 	return result;
 }
@@ -985,11 +871,14 @@ static unsigned int snd_rawmidi_poll(struct file *file, poll_table * wait)
 	rmidi = snd_magic_cast(snd_rawmidi_t, file->private_data, 0);
 
 	if (fflags & SND_RAWMIDI_LFLG_INPUT) {
-		snd_rawmidi_trigger_input(rmidi, 1);
+		snd_rawmidi_channel_t *pchn;
+		pchn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
+		pchn->flags |= SND_RAWMIDI_FLG_TRIGGER;
+		pchn->hw.trigger(rmidi, 1);
 		poll_wait(file, &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT].sleep, wait);
 	}
 	if (fflags & SND_RAWMIDI_LFLG_OUTPUT)
-		poll_wait(file, &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT].sleep, wait);
+		poll_wait(file, &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT].sleep, wait);
 	mask = 0;
 	if (fflags & SND_RAWMIDI_LFLG_INPUT) {
 		if (snd_rawmidi_input_ok(rmidi))
@@ -1082,18 +971,14 @@ int snd_rawmidi_new(snd_card_t * card, char *id, int device, snd_rawmidi_t ** rr
 	ochn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
 	rmidi->card = card;
 	rmidi->device = device;
-	ichn->lock = SPIN_LOCK_UNLOCKED;
-	ochn->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&ichn->lock);
+	spin_lock_init(&ochn->lock);
 	init_waitqueue_head(&ichn->sleep);
 	init_waitqueue_head(&ochn->sleep);
 	init_MUTEX(&rmidi->open_mutex);
 	init_waitqueue_head(&rmidi->open_wait);
 	snd_switch_prepare(card, &ichn->switches, rmidi, SND_CTL_IFACE_RAWMIDI, device, SND_RAWMIDI_CHANNEL_INPUT);
 	snd_switch_prepare(card, &ochn->switches, rmidi, SND_CTL_IFACE_RAWMIDI, device, SND_RAWMIDI_CHANNEL_OUTPUT);
-	ichn->timer.data = (unsigned long) rmidi;
-	ichn->timer.function = snd_rawmidi_poll_input;
-	ochn->timer.data = (unsigned long) rmidi;
-	ochn->timer.function = snd_rawmidi_poll_output;
 	if (id) {
 		strncpy(rmidi->id, id, sizeof(rmidi->id) - 1);
 	}
@@ -1253,24 +1138,19 @@ snd_kswitch_t *snd_rawmidi_switch_new(snd_rawmidi_channel_t * pchn, snd_kswitch_
  *  ENTRY functions
  */
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-int __init alsa_rawmidi_init(void)
-#endif
+static int __init alsa_rawmidi_init(void)
 {
 	snd_control_register_ioctl(snd_rawmidi_control_ioctl);
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_rawmidi_exit(void)
 {
 	snd_control_unregister_ioctl(snd_rawmidi_control_ioctl);
 }
 
-#endif
+module_init(alsa_rawmidi_init)
+module_exit(alsa_rawmidi_exit)
 
 EXPORT_SYMBOL(snd_rawmidi_output_params);
 EXPORT_SYMBOL(snd_rawmidi_input_params);
@@ -1280,6 +1160,7 @@ EXPORT_SYMBOL(snd_rawmidi_flush_input);
 EXPORT_SYMBOL(snd_rawmidi_receive_reset);
 EXPORT_SYMBOL(snd_rawmidi_receive);
 EXPORT_SYMBOL(snd_rawmidi_transmit_reset);
+EXPORT_SYMBOL(snd_rawmidi_transmit_empty);
 EXPORT_SYMBOL(snd_rawmidi_transmit);
 EXPORT_SYMBOL(snd_rawmidi_new);
 EXPORT_SYMBOL(snd_rawmidi_switch_add);
