@@ -237,8 +237,8 @@ static int snd_virmidi_open(unsigned short minor, int cardnum, int device,
 
 	ichn = &rmidi->chn[SND_RAWMIDI_CHANNEL_INPUT];
 	ochn = &rmidi->chn[SND_RAWMIDI_CHANNEL_OUTPUT];
-	ichn->lock = SPIN_LOCK_UNLOCKED;
-	ochn->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&ichn->lock);
+	spin_lock_init(&ochn->lock);
 	init_waitqueue_head(&ichn->sleep);
 	init_waitqueue_head(&ochn->sleep);
 
@@ -1330,24 +1330,19 @@ snd_kswitch_t *snd_virmidi_switch_new(snd_virmidi_channel_t *pchn, snd_kswitch_t
  *  ENTRY functions
  */
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-int __init alsa_virmidi_init(void)
-#endif
+static int __init alsa_virmidi_init(void)
 {
 	snd_control_register_ioctl(snd_virmidi_control_ioctl);
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_virmidi_exit(void)
 {
 	snd_control_unregister_ioctl(snd_virmidi_control_ioctl);
 }
 
-#endif
+module_init(alsa_virmidi_init)
+module_exit(alsa_virmidi_exit)
 
 EXPORT_SYMBOL(snd_virmidi_new);
 
