@@ -180,7 +180,7 @@ static ssize_t snd_write(struct file *file,
 	DEBUG_RETURN("write", minor, ptr(file, buf, count));
 }
 
-#if LinuxVersionCode(2, 3, 44) <= LINUX_VERSION_CODE
+#if KERNEL_VERSION(2, 3, 44) <= LINUX_VERSION_CODE
 static ssize_t snd_readv(struct file *file,
 			 const struct iovec *vector, unsigned long count,
 			 loff_t * offset)
@@ -333,7 +333,7 @@ struct file_operations snd_fops =
 	mmap:		snd_mmap,
 	open:		snd_open,
 	release:	snd_release,
-#if LinuxVersionCode(2, 3, 44) <= LINUX_VERSION_CODE
+#if KERNEL_VERSION(2, 3, 44) <= LINUX_VERSION_CODE
 	readv:		snd_readv,
 	writev:		snd_writev
 #endif
@@ -487,11 +487,7 @@ int __exit snd_minor_info_done(void)
  *  INIT PART
  */
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-int __init alsa_sound_init(void)
-#endif
+static int __init alsa_sound_init(void)
 {
 #ifdef CONFIG_DEVFS_FS
 	short controlnum;
@@ -500,7 +496,6 @@ int __init alsa_sound_init(void)
 #ifdef CONFIG_SND_OSSEMUL
 	int err;
 #endif
-
 	snd_ecards_limit = snd_cards_limit;
 	snd_init_minors();
 #ifdef CONFIG_SND_OSSEMUL
@@ -538,13 +533,25 @@ int __init alsa_sound_init(void)
 				snd_major, controlnum<<5, snd_device_mode | S_IFCHR,
 				0, 0, &snd_fops, NULL);
 	}
+#endif
+#ifndef MODULE
+	{
+		int idx, ok = 0;
+	
+		printk("Advanced Linux Sound Architecture Driver Version " CONFIG_SND_VERSION ".\n");
+		for (idx = 0; idx < SND_CARDS; idx++)
+			if (snd_cards[idx] != NULL) {
+				printk("  #%i: %s\n", idx, snd_cards[idx]->longname);
+				ok++;
+			}
+		if (ok == 0)
+			printk("  No soundcards found.\n");
+	}
 #endif
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_sound_exit(void)
 {
 	int idx;
 	snd_minor_t *minor;
@@ -586,7 +593,8 @@ void __exit cleanup_module(void)
 #endif
 }
 
-#endif
+module_init(alsa_sound_init)
+module_exit(alsa_sound_exit)
 
   /* sound.c */
 EXPORT_SYMBOL(snd_ecards_limit);
@@ -681,3 +689,15 @@ EXPORT_SYMBOL(snd_control_switch_new);
 EXPORT_SYMBOL(snd_control_switch_change);
   /* misc.c */
 EXPORT_SYMBOL(snd_task_name);
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,3,0)
+EXPORT_SYMBOL(snd_pci_compat_match_device);
+EXPORT_SYMBOL(snd_pci_compat_register_driver);
+EXPORT_SYMBOL(snd_pci_compat_unregister_driver);
+EXPORT_SYMBOL(snd_pci_compat_get_size);
+EXPORT_SYMBOL(snd_pci_compat_get_flags);
+EXPORT_SYMBOL(snd_pci_compat_set_power_state);
+EXPORT_SYMBOL(snd_pci_compat_enable_device);
+EXPORT_SYMBOL(snd_pci_compat_find_capability);
+EXPORT_SYMBOL(snd_pci_compat_get_driver_data);
+EXPORT_SYMBOL(snd_pci_compat_set_driver_data);
+#endif
