@@ -593,7 +593,7 @@ int snd_timer_new(snd_card_t * card, char *id, int device, snd_timer_t ** rtimer
 	if (id) {
 		strncpy(timer->id, id, sizeof(timer->id) - 1);
 	}
-	timer->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&timer->lock);
 	if (card != NULL) {
 		if ((err = snd_device_new(card, SND_DEV_TIMER, timer, device, &ops, NULL)) < 0) {
 			snd_timer_free(timer);
@@ -897,7 +897,7 @@ static int snd_timer_user_open(unsigned short minor, int cardnum, int device,
 	tu = snd_magic_kcalloc(snd_timer_user_t, 0, GFP_KERNEL);
 	if (tu == NULL)
 		return -ENOMEM;
-	tu->qlock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&tu->qlock);
 	init_waitqueue_head(&tu->qchange_sleep);
 	tu->ticks = 1;
 	tu->queue_size = 128;
@@ -1215,11 +1215,7 @@ static snd_minor_t snd_timer_reg =
 
 static snd_info_entry_t *snd_timer_proc_entry = NULL;
 
-#ifdef MODULE
-int __init init_module(void)
-#else
-int __init alsa_timer_init(void)
-#endif
+static int __init alsa_timer_init(void)
 {
 	int err;
 	snd_info_entry_t *entry;
@@ -1245,9 +1241,7 @@ int __init alsa_timer_init(void)
 	return 0;
 }
 
-#ifdef MODULE
-
-void __exit cleanup_module(void)
+static void __exit alsa_timer_exit(void)
 {
 	snd_unregister_device(SND_DEVICE_TYPE_TIMER, NULL, 0);
 	/* unregister the system timer */
@@ -1263,7 +1257,8 @@ void __exit cleanup_module(void)
 #endif
 }
 
-#endif
+module_init(alsa_timer_init)
+module_exit(alsa_timer_exit)
 
 EXPORT_SYMBOL(snd_timer_open);
 EXPORT_SYMBOL(snd_timer_open1);
