@@ -50,9 +50,6 @@ static void snd_emu10k1_pcm_ac97adc_interrupt(emu10k1_t *emu, unsigned int statu
 	if (status & IPR_ADCBUFHALFFULL) {
 		if (emu->pcm_capture_subchn->runtime->mode == SND_PCM_MODE_STREAM)
 			return;
-	} else {
-		emu10k1_pcm_t *epcm = snd_magic_cast(emu10k1_pcm_t, emu->pcm_capture_subchn->runtime->private_data, );
-		epcm->capture_oldtime = snd_emu10k1_wc(emu);
 	}
 	snd_pcm_transfer_done(emu->pcm_capture_subchn);
 }
@@ -62,9 +59,6 @@ static void snd_emu10k1_pcm_ac97mic_interrupt(emu10k1_t *emu, unsigned int statu
 	if (status & IPR_MICBUFHALFFULL) {
 		if (emu->pcm_capture_mic_subchn->runtime->mode == SND_PCM_MODE_STREAM)
 			return;
-	} else {
-		emu10k1_pcm_t *epcm = snd_magic_cast(emu10k1_pcm_t, emu->pcm_capture_mic_subchn->runtime->private_data, );
-		epcm->capture_oldtime = snd_emu10k1_wc(emu);
 	}
 	snd_pcm_transfer_done(emu->pcm_capture_mic_subchn);
 }
@@ -74,9 +68,6 @@ static void snd_emu10k1_pcm_efx_interrupt(emu10k1_t *emu, unsigned int status)
 	if (status & IPR_EFXBUFHALFFULL) {
 		if (emu->pcm_capture_efx_subchn->runtime->mode == SND_PCM_MODE_STREAM)
 			return;
-	} else {
-		emu10k1_pcm_t *epcm = snd_magic_cast(emu10k1_pcm_t, emu->pcm_capture_efx_subchn->runtime->private_data, );
-		epcm->capture_oldtime = snd_emu10k1_wc(emu);
 	}
 	snd_pcm_transfer_done(emu->pcm_capture_efx_subchn);
 }
@@ -385,9 +376,9 @@ static int snd_emu10k1_capture_prepare(void *private_data,
 	snd_emu10k1_ptr_write(emu, epcm->capture_ba_reg, 0, (unsigned int)virt_to_phys(runtime->dma_area->buf));
 	epcm->capture_bs_val = snd_emu10k1_capture_transfer_reg(epcm->capture_bufsize = snd_pcm_lib_transfer_size(subchn));
 	if (epcm->type == CAPTURE_AC97ADC) {
-		epcm->capture_cr_val = 0x08;
+		epcm->capture_cr_val = ADCCR_LCHANENABLE;
 		if (runtime->format.voices > 1)
-			epcm->capture_cr_val |= 0x10;
+			epcm->capture_cr_val |= ADCCR_RCHANENABLE;
 		epcm->capture_cr_val |= snd_emu10k1_capture_rate_reg(runtime->format.rate);
 	}
 	return 0;
@@ -485,7 +476,6 @@ static int snd_emu10k1_capture_trigger(void *private_data,
 			break;
 		}
 		snd_emu10k1_ptr_write(emu, epcm->capture_bs_reg, 0, epcm->capture_bs_val);
-		epcm->capture_oldtime = snd_emu10k1_wc(emu);
 		epcm->running = 1;
 	} else if (cmd == SND_PCM_TRIGGER_STOP) {
 		epcm->running = 0;
@@ -535,21 +525,12 @@ static unsigned int snd_emu10k1_capture_pointer(void *private_data,
 	snd_pcm_runtime_t *runtime = subchn->runtime;
 	emu10k1_pcm_t *epcm = snd_magic_cast(emu10k1_pcm_t, runtime->private_data, -ENXIO);
 	unsigned long flags;
-	unsigned int result = 0, curtime;
+	unsigned int result = 0;
 
 	spin_lock_irqsave(&emu->reg_lock, flags);
 	if (epcm->running) {
-		curtime = snd_emu10k1_wc(emu);
-		if (curtime >= epcm->capture_oldtime) {
-			result = curtime - epcm->capture_oldtime;
-		} else {
-			result = 0xfffff - (epcm->capture_oldtime - curtime);
-		}
-		result = (result * runtime->format.rate) / 48000;
-		result *= runtime->format.voices;
-		if (snd_pcm_format_width(runtime->format.format) == 16)
-			result <<= 1;
-		result %= epcm->capture_bufsize;
+		result = snd_emu10k1_ptr_read(emu, epcm->capture_idx_reg, 0) & 0x0000ffff;
+
 	}
 	spin_unlock_irqrestore(&emu->reg_lock, flags);
 	return result;
