@@ -35,28 +35,42 @@ static void snd_ac97_proc_init(snd_card_t * card, ac97_t * ac97);
 static void snd_ac97_proc_done(ac97_t * ac97);
 static void snd_ac97_chip_init(ac97_t * ac97);
 
+static struct {
+	unsigned int id;
+	char *name;
+} snd_ac97_codec_id_names[] = {
+	{	0x414b4d00,	"Asahi Kasei"			},
+	{	0x41445300,	"Analog Devices"		},
+	{	0x414c4700,	"Avance Logic"			},
+	{	0x43525900,	"Cirrus Logic"			},
+	{	0x4e534300,	"National Semiconductor"	},
+	{	0x54524100,	"TriTech"			},
+	{	0x575d4c00,	"Wolfson"			},
+	{	0x83847600,	"SigmaTel"			},
+	{	0,		NULL				}
+};
+
 static struct {
 	unsigned int id;
 	char *name;
 } snd_ac97_codec_ids[] = {
-	{	0x414B4D00,	"Asahi Kasei AK4540"	},
-	{	0x41445303,	"Analog Devices AD1819"	},
-	{	0x41445340,	"Analog Devices AD1881"	},
-	{	0x41445448,	"Analog Devices AD1885?" },
-	{	0x43525903,	"Cirrus Logic CS4297"   },
-	{	0x43525913,	"Cirrus Logic CS4297A"	},
-	{	0x42525923,	"Cirrus Logic CS4294"	},
-	{	0x43525931,	"Cirrus Logic CS4299"	},
-	{	0x43525933,	"Cirrus Logic CS4299+"	}, // some new revision?
-	{	0x4e534331,	"National Semiconductor LM4549"},
-	{	0x54524108,	"TriTech TR28028"	}, // added by xin jin [07/09/99]
-	{	0x574D4C00,	"Wolfson WM9704"	}, // added by xin jin [07/09/99]
-	{	0x83847600,	"SigmaTel STAC????"	},
-	{	0x83847604,	"SigmaTel STAC9701/3/4/5" },
-	{	0x83847605,	"SigmaTel STAC9704"	},
-	{	0x83847608,	"SigmaTel STAC9708/11"	},
-	{	0x83847609,	"SigmaTel STAC9721/23"	},
-	{	0, 		NULL			}
+	{	0x414B4D00,	"AK4540"			},
+	{	0x41445303,	"AD1819"			},
+	{	0x41445340,	"AD1881"			},
+	{	0x414c4710,	"ALC200/200P"			},
+	{	0x43525903,	"CS4297"			},
+	{	0x43525913,	"CS4297A"			},
+	{	0x42525923,	"CS4294"			},
+	{	0x43525931,	"CS4299"			},
+	{	0x43525933,	"CS4299+"			}, // some new revision?
+	{	0x4e534331,	"LM4549"			},
+	{	0x54524108,	"TR28028"			}, // added by xin jin [07/09/99]
+	{	0x574D4C00,	"WM9704"			}, // added by xin jin [07/09/99]
+	{	0x83847604,	"STAC9701/3/4/5"		},
+	{	0x83847605,	"STAC9704"			},
+	{	0x83847608,	"STAC9708/11"			},
+	{	0x83847609,	"STAC9721/23"			},
+	{	0, 		NULL				}
 };
 
 static char *snd_ac97_stereo_enhancements[] =
@@ -1892,14 +1906,13 @@ int snd_ac97_mixer(snd_card_t * card, int device,
 	if (ac97 == NULL)
 		return -ENOMEM;
 	memcpy(ac97, _ac97, sizeof(*_ac97));
-	ac97->reg_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&ac97->reg_lock);
 	if ((err = snd_mixer_new(card, "AC97", device, &mixer)) < 0) {
 		snd_magic_kfree(ac97);
 		return err;
 	}
 	mixer->private_data = ac97;
 	mixer->private_free = snd_ac97_mixer_free;
-	strcpy(mixer->name, "AC97 generic");
 	snd_ac97_write(ac97, AC97_RESET, 0);		/* reset to defaults */
 	udelay(100);
 	ac97->id = snd_ac97_read(ac97, AC97_VENDOR_ID1) << 16;
@@ -1931,37 +1944,31 @@ int snd_ac97_mixer(snd_card_t * card, int device,
 			if (snd_ac97_try_switch(ac97, &snd_ac97_sigmatel_switches[idx]))
 				snd_mixer_switch_new(mixer, &snd_ac97_sigmatel_switches[idx], ac97);
 	}
-	sprintf(ac97->name, "0x%x %c%c%c", ac97->id,
+	sprintf(mixer->name, "0x%x %c%c%c", ac97->id,
 		printable(ac97->id >> 24),
 		printable(ac97->id >> 16),
 		printable(ac97->id >> 8));
 #if 0
 	snd_printk("ac97: id = 0x%x '%c%c%c', caps = 0x%x\n", ac97->id, (unsigned char) (ac97->id >> 24), (unsigned char) (ac97->id >> 16), (unsigned char) (ac97->id >> 8), ac97->caps);
 #endif
+	for (idx = 0; snd_ac97_codec_id_names[idx].id; idx++)
+		if (snd_ac97_codec_id_names[idx].id == (ac97->id & 0xffffff00)) {
+			strcpy(mixer->name, snd_ac97_codec_id_names[idx].name);
+			goto __name_ok;
+		}
+	goto __skip;
+      __name_ok:
 	for (idx = 0; snd_ac97_codec_ids[idx].id; idx++)
 		if (snd_ac97_codec_ids[idx].id == ac97->id) {
-			strcpy(ac97->name, snd_ac97_codec_ids[idx].name);
-			strcpy(mixer->name, ac97->name);
-			ac97->rev_is_not_rev = 1;
+			strcat(mixer->name, " ");
+			strcat(mixer->name, snd_ac97_codec_ids[idx].name);
 			goto __skip;
 		}
-	// added by xin jin [07/09/99], for wolfson codec
-	for (idx = 0; snd_ac97_codec_ids[idx].id; idx++)
-		if (snd_ac97_codec_ids[idx].id == (ac97->id & 0xffffff00)) {
-			strcpy(ac97->name, snd_ac97_codec_ids[idx].name);
-			strcpy(mixer->name, ac97->name);
-			ac97->rev_is_not_rev = 1;
-			goto __skip;
-		}
-	for (idx = 0; snd_ac97_codec_ids[idx].id; idx++)
-		if ((snd_ac97_codec_ids[idx].id & 0xffffff00) == (ac97->id & 0xffffff00)) {
-			strcpy(ac97->name, snd_ac97_codec_ids[idx].name);
-			strcpy(mixer->name, ac97->name);
-			break;
-		}
+	sprintf(mixer->name + strlen(mixer->name), " (%x)\n", ac97->id & 0xff);
       __skip:
 	snd_ac97_chip_init(ac97);
 	snd_ac97_proc_init(card, ac97);
+	ac97->mixer = mixer;
 	*rmixer = mixer;
 	return 0;
 }
@@ -1975,11 +1982,7 @@ static void snd_ac97_proc_read(snd_info_buffer_t * buffer, void *private_data)
 	unsigned short val, ext;
 	ac97_t *ac97 = snd_magic_cast(ac97_t, private_data, );
 
-	if (ac97->rev_is_not_rev) {
-		snd_iprintf(buffer, "%s\n\n", ac97->name);
-	} else {
-		snd_iprintf(buffer, "%s rev %i\n\n", ac97->name, ac97->id & 0xff);
-	}
+	snd_iprintf(buffer, "%s\n\n", ac97->mixer->name);
 	snd_iprintf(buffer, "Capabilities     :%s%s%s%s%s%s\n",
 	    ac97->caps & 0x0001 ? " -dedicated MIC PCM IN channel-" : "",
 		    ac97->caps & 0x0002 ? " -reserved1-" : "",
@@ -2235,15 +2238,14 @@ EXPORT_SYMBOL(snd_ac97_mixer);
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_ac97_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_ac97_exit(void)
 {
 }
 
-#endif
+module_init(alsa_ac97_init)
+module_exit(alsa_ac97_exit)
