@@ -1325,7 +1325,7 @@ snd_sf_new(snd_sf_callback_t *callback, snd_emux_memhdr_t *hdr)
 		return NULL;
 
 	init_MUTEX(&sflist->presets_mutex);
-	sflist->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&sflist->lock);
 	sflist->sf_locked = 0;
 	sflist->memhdr = hdr;
 
