@@ -106,7 +106,7 @@
 #define SERIAL_MODE_OUTPUT_OPEN (1 << 1)
 
 #define SERIAL_MODE_INPUT_TRIGGERED (1 << 2)
-#define SERIAL_MODE_OUTPUT_TRIGGERD (1 << 3)
+#define SERIAL_MODE_OUTPUT_TRIGGERED (1 << 3)
 
 #define SERIAL_TRUE (1)
 #define SERIAL_FALSE (0)
@@ -129,7 +129,7 @@ static snd_uart16550_t *snd_uart16550_t_new(snd_card_t * card)
 	uart->prev_ports = 0;
 	uart->filemode = 0;
 	uart->irq = NULL;
-	uart->open_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&uart->open_lock);
 
 	return uart;
 }
@@ -604,6 +604,24 @@ static void snd_uart16550_output_write(snd_rawmidi_t * rmidi)
 	//snd_printd ("snd_uart16550_output_write done\n");
 }
 
+static void snd_uart16550_output_trigger(snd_rawmidi_t * rmidi, int up)
+{
+	unsigned long flags;
+	snd_uart16550_t *uart;
+
+	snd_printd("snd_uart16550_output_trigger called\n");
+	uart = snd_magic_cast(snd_uart16550_t, rmidi->private_data, );
+
+	spin_lock_irqsave(&uart->open_lock, flags);
+	if (up) {
+		uart->filemode |= SERIAL_MODE_OUTPUT_TRIGGERED;
+	} else {
+		uart->filemode &= ~SERIAL_MODE_OUTPUT_TRIGGERED;
+	}
+	spin_unlock_irqrestore(&uart->open_lock, flags);
+	if (up)
+		snd_uart16550_output_write(rmidi);
+}
 
 ////////////////////////////////////////////////////////////////
 /* This loop should be called with interrupts disabled
@@ -653,11 +671,9 @@ static int snd_uart16550_register_resources(snd_uart16550_t * uart)
 
 static struct snd_stru_rawmidi_channel_hw snd_uart16550_output =
 {
-	flags:		SND_RAWMIDI_HW_POLL,
 	open:		snd_uart16550_output_open,
 	close:		snd_uart16550_output_close,
-	io:		{write: snd_uart16550_output_write},
-
+	trigger:	snd_uart16550_output_trigger,
 };
 
 static struct snd_stru_rawmidi_channel_hw snd_uart16550_input =
@@ -665,7 +681,6 @@ static struct snd_stru_rawmidi_channel_hw snd_uart16550_input =
 	open:		snd_uart16550_input_open,
 	close:		snd_uart16550_input_close,
 	trigger:	snd_uart16550_input_trigger,
-
 };
 
 
@@ -754,15 +769,14 @@ EXPORT_SYMBOL(snd_uart16550_new_device);
 EXPORT_SYMBOL(snd_uart16550_set_param);
 EXPORT_SYMBOL(snd_uart16550_detect);
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_uart16550_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_uart16550_exit(void)
 {
 }
 
-#endif
+module_init(alsa_uart16550_init)
+module_exit(alsa_uart16550_exit)
