@@ -925,11 +925,14 @@ EXPORT_SYMBOL(snd_hal2_free);
 EXPORT_SYMBOL(snd_hal2_interrupt);
 EXPORT_SYMBOL(snd_hal2_pcm);
 
-int init_module(void)
+static int __init alsa_hal2_init(void)
 {
 	return 0;
 }
 
-void cleanup_module(void)
+static void __exit alsa_hal2_exit(void)
 {
 }
+
+module_init(alsa_hal2_init)
+module_exit(alsa_hal2_exit)
