@@ -561,7 +561,7 @@ int snd_ad1816a_new_pcm(snd_card_t *card, int device,
 	codec->dma2 = dma2ptr->dma;
 	codec->dma1ptr = dma1ptr;
 	codec->dma2ptr = dma2ptr;
-	codec->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&codec->lock);
 
 	pcm->chn[SND_PCM_CHANNEL_PLAYBACK].private_data = codec;
 	pcm->chn[SND_PCM_CHANNEL_PLAYBACK].open = snd_ad1816a_playback_open;
@@ -1789,16 +1789,14 @@ EXPORT_SYMBOL(snd_ad1816a_interrupt);
 EXPORT_SYMBOL(snd_ad1816a_new_pcm);
 EXPORT_SYMBOL(snd_ad1816a_new_mixer);
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_ad1816a_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_ad1816a_exit(void)
 {
 }
 
-#endif	/* MODULE */
-
+module_init(alsa_ad1816a_init)
+module_exit(alsa_ad1816a_exit)
