@@ -854,7 +854,7 @@ int snd_ad1848_new_pcm(snd_card_t * card, int device,
 		snd_device_free(card, pcm);
 		return -ENOMEM;
 	}
-	codec->reg_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&codec->reg_lock);
 	init_MUTEX(&codec->open_mutex);
 	codec->pcm = pcm;
 	codec->card = pcm->card;
@@ -1565,15 +1565,14 @@ EXPORT_SYMBOL(snd_ad1848_mixer_mono_switch);
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_ad1848_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_ad1848_exit(void)
 {
 }
 
-#endif
+module_init(alsa_ad1848_init)
+module_exit(alsa_ad1848_exit)
