@@ -1321,7 +1321,7 @@ int snd_cs4231_new_pcm(snd_card_t * card, int device,
 		snd_device_free(card, pcm);
 		return -ENOMEM;
 	}
-	codec->reg_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&codec->reg_lock);
 	init_MUTEX(&codec->mce_mutex);
 	init_MUTEX(&codec->open_mutex);
 	codec->pcm = pcm;
@@ -2269,15 +2269,14 @@ EXPORT_SYMBOL(snd_cs4231_mixer_group_ctrl1);
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_cs4231_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_cs4231_exit(void)
 {
 }
 
-#endif
+module_init(alsa_cs4231_init)
+module_exit(alsa_cs4231_exit)
