@@ -2244,11 +2244,14 @@ EXPORT_SYMBOL(snd_cs4236_new_mixer);
  *  INIT part
  */
 
-int init_module(void)
+static int __init alsa_cs4236_init(void)
 {
 	return 0;
 }
 
-void cleanup_module(void)
+static void __exit alsa_cs4236_exit(void)
 {
 }
+
+module_init(alsa_cs4236_init)
+module_exit(alsa_cs4236_exit)
