@@ -1132,9 +1132,9 @@ int snd_es18xx_new_device(snd_card_t * card,
         codec = snd_magic_kcalloc(es18xx_t, 0, GFP_KERNEL);
 	if (codec == NULL)
 		return -ENOMEM;
-	codec->reg_lock = SPIN_LOCK_UNLOCKED;
-        codec->mixer_lock = SPIN_LOCK_UNLOCKED;
-        codec->ctrl_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&codec->reg_lock);
+ 	spin_lock_init(&codec->mixer_lock);
+ 	spin_lock_init(&codec->ctrl_lock);
         codec->card = card;
         codec->port = port;
         codec->mpu_port = mpu_port;
@@ -2223,15 +2223,14 @@ EXPORT_SYMBOL(snd_es18xx_pcm);
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_es18xx_init(void)
 {
         return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_es18xx_exit(void)
 {
 }
 
-#endif
+module_init(alsa_es18xx_init)
+module_exit(alsa_es18xx_exit)
