@@ -749,7 +749,7 @@ int snd_opti93x_new_pcm(snd_card_t *card, int device, opti9xx_t *chip,
 	codec->dma1ptr = dma1ptr;
 	codec->dma2ptr = dma2ptr;
 
-	codec->lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&codec->lock);
 	codec->hardware = chip->hardware;
 	codec->chip = chip;
 
@@ -1686,16 +1686,14 @@ EXPORT_SYMBOL(snd_opti93x_interrupt);
 EXPORT_SYMBOL(snd_opti93x_new_pcm);
 EXPORT_SYMBOL(snd_opti93x_new_mixer);
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_opti93x_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_opti93x_exit(void)
 {
 }
 
-#endif
-
+module_init(alsa_opti93x_init)
+module_exit(alsa_opti93x_exit)
