@@ -913,19 +913,28 @@ void snd_cs461x_interrupt(cs461x_t *codec)
 	}
 	if ((status & HISR_MIDI) && codec->rmidi) {
 		unsigned char c;
+		unsigned long flags;
+		
+		spin_lock_irqsave(&codec->reg_lock, flags);
 		while ((snd_cs461x_peekBA0(codec, BA0_MIDSR) & MIDSR_RBE) == 0) {
 			c = snd_cs461x_peekBA0(codec, BA0_MIDRP);
 			if ((codec->midcr & MIDCR_RIE) == 0)
 				continue;
+			spin_unlock_irqrestore(&codec->reg_lock, flags);
 			snd_rawmidi_receive(codec->rmidi, &c, 1);
+			spin_lock_irqsave(&codec->reg_lock, flags);
 		}
 		while ((snd_cs461x_peekBA0(codec, BA0_MIDSR) & MIDSR_TBF) == 0) {
 			if ((codec->midcr & MIDCR_TIE) == 0)
 				break;
-			if (snd_rawmidi_transmit(codec->rmidi, &c, 1) != 1)
+			if (snd_rawmidi_transmit(codec->rmidi, &c, 1) != 1) {
+				codec->midcr &= ~MIDCR_TIE;
+				snd_cs461x_pokeBA0(codec, BA0_MIDCR, codec->midcr);
 				break;
+			}
 			snd_cs461x_pokeBA0(codec, BA0_MIDWP, c);
 		}
+		spin_unlock_irqrestore(&codec->reg_lock, flags);
 	}
 	/*
 	 *  EOI to the PCI part....reenables interrupts
@@ -1191,11 +1200,17 @@ static void snd_cs461x_midi_input_trigger(snd_rawmidi_t * rmidi, int up)
 	cs461x_t *codec = snd_magic_cast(cs461x_t, rmidi->private_data, );
 
 	spin_lock_irqsave(&codec->reg_lock, flags);
-	if (up)
-		codec->midcr |= MIDCR_RIE;
-	else
-		codec->midcr &= ~MIDCR_RIE;
-	snd_cs461x_pokeBA0(codec, BA0_MIDCR, codec->midcr);
+	if (up) {
+		if ((codec->midcr & MIDCR_RIE) == 0) {
+			codec->midcr |= MIDCR_RIE;
+			snd_cs461x_pokeBA0(codec, BA0_MIDCR, codec->midcr);
+		}
+	} else {
+		if (codec->midcr & MIDCR_RIE) {
+			codec->midcr &= ~MIDCR_RIE;
+			snd_cs461x_pokeBA0(codec, BA0_MIDCR, codec->midcr);
+		}
+	}
 	spin_unlock_irqrestore(&codec->reg_lock, flags);
 }
 
@@ -1203,24 +1218,29 @@ static void snd_cs461x_midi_output_trigger(snd_rawmidi_t * rmidi, int up)
 {
 	unsigned long flags;
 	cs461x_t *codec = snd_magic_cast(cs461x_t, rmidi->private_data, );
+	unsigned char byte;
 
 	spin_lock_irqsave(&codec->reg_lock, flags);
 	if (up) {
-		codec->midcr |= MIDCR_TIE;
-		/* fill UART FIFO buffer at first, and turn Tx interrupts only if necessary */
-		while ((codec->midcr & MIDCR_TIE) &&
-		       (snd_cs461x_peekBA0(codec, BA0_MIDSR) & MIDSR_TBF) == 0) {
-			unsigned char byte;
-			if (snd_rawmidi_transmit(rmidi, &byte, 1) != 1) {
-				codec->midcr &= ~MIDCR_TIE;
-			} else {
-				snd_cs461x_pokeBA0(codec, BA0_MIDWP, byte);
+		if ((codec->midcr & MIDCR_TIE) == 0) {
+			codec->midcr |= MIDCR_TIE;
+			/* fill UART FIFO buffer at first, and turn Tx interrupts only if necessary */
+			while ((codec->midcr & MIDCR_TIE) &&
+			       (snd_cs461x_peekBA0(codec, BA0_MIDSR) & MIDSR_TBF) == 0) {
+				if (snd_rawmidi_transmit(rmidi, &byte, 1) != 1) {
+					codec->midcr &= ~MIDCR_TIE;
+				} else {
+					snd_cs461x_pokeBA0(codec, BA0_MIDWP, byte);
+				}
 			}
+			snd_cs461x_pokeBA0(codec, BA0_MIDCR, codec->midcr);
 		}
 	} else {
-		codec->midcr &= ~MIDCR_TIE;
+		if (codec->midcr & MIDCR_TIE) {
+			codec->midcr &= ~MIDCR_TIE;
+			snd_cs461x_pokeBA0(codec, BA0_MIDCR, codec->midcr);
+		}
 	}
-	snd_cs461x_pokeBA0(codec, BA0_MIDCR, codec->midcr);
 	spin_unlock_irqrestore(&codec->reg_lock, flags);
 }
 
@@ -1425,19 +1445,14 @@ int snd_cs461x_create(snd_card_t * card,
 	codec = snd_magic_kcalloc(cs461x_t, 0, GFP_KERNEL);
 	if (codec == NULL)
 		return -ENOMEM;
-	codec->reg_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&codec->reg_lock);
 	codec->card = card;
 	codec->pci = pci;
 	codec->dma1ptr = dma1ptr;
 	codec->dma2ptr = dma2ptr;
 	codec->irqptr = irqptr;
-#ifdef NEW_PCI
-	codec->ba0_addr = pci->resource[0].start;
-	codec->ba1_addr = pci->resource[1].start;
-#else
-	codec->ba0_addr = pci->base_address[0] & ~PCI_BASE_ADDRESS_SPACE;
-	codec->ba1_addr = pci->base_address[1] & ~PCI_BASE_ADDRESS_SPACE;
-#endif
+	codec->ba0_addr = pci_resource_start(pci, 0);
+	codec->ba1_addr = pci_resource_start(pci, 1);
 	if (codec->ba0_addr == 0 || codec->ba0_addr == ~0 ||
 	    codec->ba1_addr == 0 || codec->ba1_addr == ~0) {
 	    	snd_printk("cs461x: wrong address(es) - ba0 = 0x%lx, ba1 = 0x%lx\n", codec->ba0_addr, codec->ba1_addr);
@@ -1776,15 +1791,14 @@ EXPORT_SYMBOL(snd_cs461x_midi);
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_cs461x_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_cs461x_exit(void)
 {
 }
 
-#endif
+module_init(alsa_cs461x_init)
+module_exit(alsa_cs461x_exit)
