@@ -1359,18 +1359,14 @@ int snd_ensoniq_create(snd_card_t * card,
 	ensoniq = snd_magic_kcalloc(ensoniq_t, 0, GFP_KERNEL);
 	if (ensoniq == NULL)
 		return -ENOMEM;
-	ensoniq->reg_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&ensoniq->reg_lock);
 	ensoniq->card = card;
 	ensoniq->pci = pci;
 	ensoniq->dma1ptr = dma1ptr;
 	ensoniq->dma2ptr = dma2ptr;
 	ensoniq->dma3ptr = dma3ptr;
 	ensoniq->irqptr = irqptr;
-#ifdef NEW_PCI
-	ensoniq->port = pci->resource[0].start;
-#else
-	ensoniq->port = pci->base_address[0] & ~PCI_BASE_ADDRESS_SPACE;
-#endif
+	ensoniq->port = pci_resource_start(pci, 0);
 	pci_read_config_word(pci, PCI_COMMAND, &cmdw);
 	if ((cmdw & PCI_COMMAND_IO) != PCI_COMMAND_IO) {
 		cmdw |= PCI_COMMAND_IO;
@@ -1506,38 +1502,39 @@ static void snd_ensoniq_midi_interrupt(ensoniq_t * ensoniq,
 				       snd_rawmidi_t * rmidi)
 {
 	unsigned long flags;
-	unsigned char status, mask = 0, byte;
+	unsigned char status, mask, byte;
 
+	/* do Tx at first */
 	spin_lock_irqsave(&ensoniq->reg_lock, flags);
-	if (ensoniq->uartm & ES_MODE_INPUT)
-		mask |= ES_RXRDY;
-	if (ensoniq->uartm & ES_MODE_OUTPUT)
-		mask |= ES_TXRDY;
-	while (1) {
+	mask = ensoniq->uartm & ES_MODE_OUTPUT ? ES_TXRDY : 0;
+	while (mask) {
 		status = inb(ES_REG(ensoniq, UART_STATUS));
 		if ((status & mask) == 0)
 			break;
-		if (status & ES_RXRDY) {
-			byte = inb(ES_REG(ensoniq, UART_DATA));
-			if (mask & ES_RXRDY)
-				snd_rawmidi_receive(rmidi, &byte, 1);
-		} else if (status & ES_TXRDY) {
-			if (mask & ES_TXRDY) {
-				spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
-				if (snd_rawmidi_transmit(rmidi, &byte, 1) != 1) {
-					spin_lock_irqsave(&ensoniq->reg_lock, flags);
-					ensoniq->uartc &= ~ES_TXINTENM;
-					mask &= ~ES_TXRDY;
-				} else {
-					spin_lock_irqsave(&ensoniq->reg_lock, flags);
-					outb(byte, ES_REG(ensoniq, UART_DATA));
-				}
-			} else {
-				ensoniq->uartc &= ~ES_TXINTENM;
-			}
+		if (snd_rawmidi_transmit(rmidi, &byte, 1) != 1) {
+			ensoniq->uartc &= ~ES_TXINTENM;
+			outb(ensoniq->uartc, ES_REG(ensoniq, UART_CONTROL));
+			mask &= ~ES_TXRDY;
+		} else {
+			outb(byte, ES_REG(ensoniq, UART_DATA));
+		}
+	}
+	spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
+
+	/* do Rx at second */
+	spin_lock_irqsave(&ensoniq->reg_lock, flags);
+	mask = ensoniq->uartm & ES_MODE_INPUT ? ES_RXRDY : 0;
+	while (mask) {
+		status = inb(ES_REG(ensoniq, UART_STATUS));
+		if ((status & mask) == 0)
+			break;
+		byte = inb(ES_REG(ensoniq, UART_DATA));
+		if (mask & ES_RXRDY) {
+			spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
+			snd_rawmidi_receive(rmidi, &byte, 1);
+			spin_lock_irqsave(&ensoniq->reg_lock, flags);
 		}
 	}
-	outb(ensoniq->uartc, ES_REG(ensoniq, UART_CONTROL));
 	spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
 }
 
@@ -1611,13 +1608,23 @@ static void snd_ensoniq_midi_input_trigger(snd_rawmidi_t * rmidi, int up)
 {
 	unsigned long flags;
 	ensoniq_t *ensoniq = snd_magic_cast(ensoniq_t, rmidi->private_data, );
+	int idx;
 
 	spin_lock_irqsave(&ensoniq->reg_lock, flags);
-	if (up)
-		ensoniq->uartc |= ES_RXINTEN;
-	else
-		ensoniq->uartc &= ~ES_RXINTEN;
-	outb(ensoniq->uartc, ES_REG(ensoniq, UART_CONTROL));
+	if (up) {
+		if ((ensoniq->uartc & ES_RXINTEN) == 0) {
+			/* empty input FIFO */
+			for (idx = 0; idx < 32; idx++)
+				inb(ES_REG(ensoniq, UART_DATA));
+			ensoniq->uartc |= ES_RXINTEN;
+			outb(ensoniq->uartc, ES_REG(ensoniq, UART_CONTROL));
+		}
+	} else {
+		if (ensoniq->uartc & ES_RXINTEN) {
+			ensoniq->uartc &= ~ES_RXINTEN;
+			outb(ensoniq->uartc, ES_REG(ensoniq, UART_CONTROL));
+		}
+	}
 	spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
 }
 
@@ -1625,27 +1632,29 @@ static void snd_ensoniq_midi_output_trigger(snd_rawmidi_t * rmidi, int up)
 {
 	unsigned long flags;
 	ensoniq_t *ensoniq = snd_magic_cast(ensoniq_t, rmidi->private_data, );
+	unsigned char byte;
 
 	spin_lock_irqsave(&ensoniq->reg_lock, flags);
 	if (up) {
-		ensoniq->uartc |= ES_TXINTENO(1);
-		/* fill UART FIFO buffer at first, and turn Tx interrupts only if necessary */
-		while (ES_TXINTENI(ensoniq->uartc) == 1 &&
-		       (inb(ES_REG(ensoniq, UART_STATUS)) & ES_TXRDY)) {
-			unsigned char byte;
-			spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
-			if (snd_rawmidi_transmit(rmidi, &byte, 1) != 1) {
-				spin_lock_irqsave(&ensoniq->reg_lock, flags);
-				ensoniq->uartc &= ~ES_TXINTENM;
-			} else {
-				spin_lock_irqsave(&ensoniq->reg_lock, flags);
-				outb(byte, ES_REG(ensoniq, UART_DATA));
+		if (ES_TXINTENI(ensoniq->uartc) == 0) {
+			ensoniq->uartc |= ES_TXINTENO(1);
+			/* fill UART FIFO buffer at first, and turn Tx interrupts only if necessary */
+			while (ES_TXINTENI(ensoniq->uartc) == 1 &&
+			       (inb(ES_REG(ensoniq, UART_STATUS)) & ES_TXRDY)) {
+				if (snd_rawmidi_transmit(rmidi, &byte, 1) != 1) {
+					ensoniq->uartc &= ~ES_TXINTENM;
+				} else {
+					outb(byte, ES_REG(ensoniq, UART_DATA));
+				}
 			}
+			outb(ensoniq->uartc, ES_REG(ensoniq, UART_CONTROL));
 		}
 	} else {
-		ensoniq->uartc &= ~ES_TXINTENM;
+		if (ES_TXINTENI(ensoniq->uartc) == 1) {
+			ensoniq->uartc &= ~ES_TXINTENM;
+			outb(ensoniq->uartc, ES_REG(ensoniq, UART_CONTROL));
+		}
 	}
-	outb(ensoniq->uartc, ES_REG(ensoniq, UART_CONTROL));
 	spin_unlock_irqrestore(&ensoniq->reg_lock, flags);
 }
 
@@ -1746,15 +1755,14 @@ EXPORT_SYMBOL(snd_ensoniq_1371_mixer);
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_ens137x_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_ens137x_exit(void)
 {
 }
 
-#endif
+module_init(alsa_ens137x_init)
+module_exit(alsa_ens137x_exit)
