@@ -1740,7 +1740,7 @@ int snd_ice1712_create(snd_card_t * card,
 	ice = snd_magic_kcalloc(ice1712_t, 0, GFP_KERNEL);
 	if (ice == NULL)
 		return -ENOMEM;
-	ice->reg_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&ice->reg_lock);
 	ice->spdif_defaults = 0x01 |		/* consumer format */
 			      0x10 |		/* no emphasis */
 			      0x20;		/* PCM encoder/decoder */
@@ -1751,17 +1751,10 @@ int snd_ice1712_create(snd_card_t * card,
 	ice->dma_prop = dma_prop;
 	ice->dma_proc = dma_proc;
 	ice->irqptr = irqptr;
-#ifdef NEW_PCI
-	ice->port = pci->resource[0].start;
-	ice->ddma_port = pci->resource[1].start;
-	ice->dmapath_port = pci->resource[2].start;
-	ice->profi_port = pci->resource[3].start;
-#else
-	ice->port = pci->base_address[0] & ~PCI_BASE_ADDRESS_SPACE;
-	ice->ddma_port = pci->base_address[1] & ~PCI_BASE_ADDRESS_SPACE;
-	ice->dmapath_port = pci->base_address[2] & ~PCI_BASE_ADDRESS_SPACE;
-	ice->profi_port = pci->base_address[3] & ~PCI_BASE_ADDRESS_SPACE;
-#endif
+	ice->port = pci_resource_start(pci, 0);
+	ice->ddma_port = pci_resource_start(pci, 1);
+	ice->dmapath_port = pci_resource_start(pci, 2);
+	ice->profi_port = pci_resource_start(pci, 3);
 	pci_read_config_word(pci, PCI_COMMAND, &cmdw);
 	if ((cmdw & PCI_COMMAND_IO) != PCI_COMMAND_IO) {
 		cmdw |= PCI_COMMAND_IO;
@@ -1819,15 +1812,14 @@ EXPORT_SYMBOL(snd_ice1712_mixer);
  *  INIT part
  */
 
-#ifdef MODULE
-
-int __init init_module(void)
+static int __init alsa_ice1712_init(void)
 {
 	return 0;
 }
 
-void __exit cleanup_module(void)
+static void __exit alsa_ice1712_exit(void)
 {
 }
 
-#endif
+module_init(alsa_ice1712_init)
+module_exit(alsa_ice1712_exit)
