@@ -78,40 +78,45 @@ static int snd_sb16_playback_prepare(void *private_data, snd_pcm_subchn_t * subc
 		snd_sb_csp_t *csp = snd_magic_cast(snd_sb_csp_t, codec->csp_private_data, -ENXIO);
 		if (csp->running & SND_SB_CSP_ST_LOADED) {
 			/* manually loaded codec */
-
-			/* Check if supported runtime PCM format for playback ... */
-			if (((csp->mode & SND_SB_CSP_MODE_DSP_WRITE) && ((1 << runtime->format.format) == csp->acc_format)) ||
-			    /* ... or QSound decoder is loaded and enabled ... */
-			    ((csp->mode & SND_SB_CSP_MODE_QSOUND) && (csp->q_enabled) &&
-			     /* ... for simple PCM formats */
-			     ((1 << runtime->format.format) & (SND_PCM_FMT_S8 | SND_PCM_FMT_U8 |
-							       SND_PCM_FMT_S16_LE | SND_PCM_FMT_U16_LE ))))
-				if (!(csp_callbacks->csp_use(csp))) {
-					if (csp_callbacks->csp_start(csp, (codec->mode16 & SB_MODE16_PLAYBACK16) ?
-								     SND_SB_CSP_SAMPLE_16BIT : SND_SB_CSP_SAMPLE_8BIT,
-								     (runtime->format.voices > 1) ?
-								     SND_SB_CSP_STEREO : SND_SB_CSP_MONO))
-						csp_callbacks->csp_unuse(csp);
-					else
-						codec->csp_acquired = SND_SB_CSP_MODE_DSP_WRITE;
+			if ((csp->mode & SND_SB_CSP_MODE_DSP_WRITE) &&
+			    ((1 << runtime->format.format) == csp->acc_format)) {
+				/* Supported runtime PCM format for playback */
+				if (csp_callbacks->csp_use(csp) == 0) {
+					/* If CSP was successfully acquired */
+					goto __start_CSP;
 				}
-		} else {
-			/* autoloaded hardware codec */
-			if (!(csp_callbacks->csp_use(csp))) {
-				if (csp_callbacks->csp_autoload(csp, runtime->format.format, SND_SB_CSP_MODE_DSP_WRITE)) {
+			} else if ((csp->mode & SND_SB_CSP_MODE_QSOUND) && (csp->q_enabled)) {
+				/* QSound decoder is loaded and enabled */
+				if ((1 << runtime->format.format) & (SND_PCM_FMT_S8 | SND_PCM_FMT_U8 |
+								     SND_PCM_FMT_S16_LE | SND_PCM_FMT_U16_LE)) {
+					/* Only for simple PCM formats */
+					if (csp_callbacks->csp_use(csp) == 0) {
+						/* If CSP was successfully acquired */
+						goto __start_CSP;
+					}
+				}
+			}
+		} else if (csp_callbacks->csp_use(csp) == 0) {
+			/* Acquire CSP and try to autoload hardware codec */
+			if (csp_callbacks->csp_autoload(csp, runtime->format.format, SND_SB_CSP_MODE_DSP_WRITE)) {
+				/* Unsupported format, release CSP */
+				csp_callbacks->csp_unuse(csp);
+			} else {
+		      __start_CSP:
+				/* Try to start CSP */
+				if (csp_callbacks->csp_start(csp, (codec->mode16 & SB_MODE16_PLAYBACK16) ?
+							     SND_SB_CSP_SAMPLE_16BIT : SND_SB_CSP_SAMPLE_8BIT,
+							     (runtime->format.voices > 1) ?
+							     SND_SB_CSP_STEREO : SND_SB_CSP_MONO)) {
+					/* Failed, release CSP */
 					csp_callbacks->csp_unuse(csp);
 				} else {
-					if (csp_callbacks->csp_start(csp, (codec->mode16 & SB_MODE16_PLAYBACK16) ?
-								     SND_SB_CSP_SAMPLE_16BIT : SND_SB_CSP_SAMPLE_8BIT,
-								     (runtime->format.voices > 1) ?
-								     SND_SB_CSP_STEREO : SND_SB_CSP_MONO))
-						csp_callbacks->csp_unuse(csp);
-					else
-						codec->csp_acquired = SND_SB_CSP_MODE_DSP_WRITE;
+					/* Success, CSP acquired and running */
+					codec->csp_acquired = SND_SB_CSP_MODE_DSP_WRITE;
 				}
 			}
 		}
-	}   
+	}
 #endif
 	if (snd_pcm_format_unsigned(runtime->format.format) > 0) {
 		format = runtime->format.voices > 1 ? SB_DSP4_MODE_UNS_STEREO : SB_DSP4_MODE_UNS_MONO;
@@ -192,34 +197,33 @@ static int snd_sb16_capture_prepare(void *private_data,
 	if (codec->hardware == SB_HW_16CSP) {
 		snd_sb_csp_callback_t *csp_callbacks = (snd_sb_csp_callback_t *) codec->csp_callbacks;
 		snd_sb_csp_t *csp = snd_magic_cast(snd_sb_csp_t, codec->csp_private_data, -ENXIO);
-
 		if (csp->running & SND_SB_CSP_ST_LOADED) {
 			/* manually loaded codec */
-
-			/* check if supported runtime PCM format for capture ... */
-			if ((csp->mode & SND_SB_CSP_MODE_DSP_READ) && ((1 << runtime->format.format) == csp->acc_format))
-				if (!(csp_callbacks->csp_use(csp))) {
-					if (csp_callbacks->csp_start(csp, (codec->mode16 & SB_MODE16_CAPTURE16) ?
-								     SND_SB_CSP_SAMPLE_16BIT : SND_SB_CSP_SAMPLE_8BIT,
-								     (runtime->format.voices > 1) ?
-								     SND_SB_CSP_STEREO : SND_SB_CSP_MONO))
-						csp_callbacks->csp_unuse(csp);
-					else
-						codec->csp_acquired = SND_SB_CSP_MODE_DSP_READ;
+			if ((csp->mode & SND_SB_CSP_MODE_DSP_READ) &&
+			    ((1 << runtime->format.format) == csp->acc_format)) {
+				/* Supported runtime PCM format for capture */
+				if (csp_callbacks->csp_use(csp) == 0) {
+					/* If CSP was successfully acquired */
+					goto __start_CSP;
 				}
-		} else {
-			/* autoloaded hardware codec */
-			if (!(csp_callbacks->csp_use(csp))) {
-				if (csp_callbacks->csp_autoload(csp, runtime->format.format, SND_SB_CSP_MODE_DSP_READ)) {
+			}
+		} else if (csp_callbacks->csp_use(csp) == 0) {
+			/* Acquire CSP and try to autoload hardware codec */
+			if (csp_callbacks->csp_autoload(csp, runtime->format.format, SND_SB_CSP_MODE_DSP_READ)) {
+				/* Unsupported format, release CSP */
+				csp_callbacks->csp_unuse(csp);
+			} else {
+		      __start_CSP:
+				/* Try to start CSP */
+				if (csp_callbacks->csp_start(csp, (codec->mode16 & SB_MODE16_CAPTURE16) ?
+							     SND_SB_CSP_SAMPLE_16BIT : SND_SB_CSP_SAMPLE_8BIT,
+							     (runtime->format.voices > 1) ?
+							     SND_SB_CSP_STEREO : SND_SB_CSP_MONO)) {
+					/* Failed, release CSP */
 					csp_callbacks->csp_unuse(csp);
 				} else {
-					if (csp_callbacks->csp_start(csp, (codec->mode16 & SB_MODE16_CAPTURE16) ?
-								     SND_SB_CSP_SAMPLE_16BIT : SND_SB_CSP_SAMPLE_8BIT,
-								     (runtime->format.voices > 1) ?
-								     SND_SB_CSP_STEREO : SND_SB_CSP_MONO))
-						csp_callbacks->csp_unuse(csp);
-					else
-						codec->csp_acquired = SND_SB_CSP_MODE_DSP_READ;
+					/* Success, CSP acquired and running */
+					codec->csp_acquired = SND_SB_CSP_MODE_DSP_READ;
 				}
 			}
 		}
@@ -518,7 +522,7 @@ int snd_sb16_capture_open(void *private_data, snd_pcm_subchn_t * subchn)
 				} else {
 					/* autoloaded codecs */
 					runtime->hw->formats |= SND_PCM_FMT_MU_LAW | SND_PCM_FMT_A_LAW |
-							       SND_PCM_FMT_IMA_ADPCM;
+								SND_PCM_FMT_IMA_ADPCM;
 				}
 			}
 #endif
