@@ -964,7 +964,7 @@ static int snd_sb16_mixer_qsound_build(snd_sb_csp_t * p)
 	if (p->qsound_element)
 		return 0;
 
-	p->q_lock = SPIN_LOCK_UNLOCKED;
+	spin_lock_init(&p->q_lock);
 
 	snd_mixer_lock(mixer, 0);
 	/* build 3d effect1 group */
@@ -1130,10 +1130,14 @@ EXPORT_SYMBOL(snd_sb_csp_register_callbacks);
  * INIT part
  */
 
-int __init init_module(void)
+static int __init alsa_sb16_csp_init(void)
 {
 	return 0;
 }
-void __exit cleanup_module(void)
+
+static void __exit alsa_sb16_csp_exit(void)
 {
 }
+
+module_init(alsa_sb16_csp_init)
+module_exit(alsa_sb16_csp_exit)
