@@ -432,7 +432,7 @@ static snd_pcm_hardware_t snd_sb8_playback =
 	SND_PCM_CHNINFO_BLOCK | SND_PCM_CHNINFO_INTERLEAVE |
 	SND_PCM_CHNINFO_MMAP_VALID,	/* flags */
 	SND_PCM_FMT_U8,		/* formats */
-	SND_PCM_RATE_PLL | SND_PCM_RATE_8000 |
+	SND_PCM_RATE_CONTINUOUS | SND_PCM_RATE_8000 |
 	SND_PCM_RATE_11025 | SND_PCM_RATE_22050,
 	4000,			/* min. rate */
 	23000,			/* max. rate */
@@ -455,7 +455,7 @@ static snd_pcm_hardware_t snd_sb8_capture =
 	SND_PCM_CHNINFO_BLOCK | SND_PCM_CHNINFO_INTERLEAVE |
 	SND_PCM_CHNINFO_MMAP_VALID,	/* flags */
 	SND_PCM_FMT_U8,		/* formats */
-	SND_PCM_RATE_PLL | SND_PCM_RATE_8000 |
+	SND_PCM_RATE_CONTINUOUS | SND_PCM_RATE_8000 |
 	SND_PCM_RATE_11025,
 	4000,			/* min. rate */
 	13000,			/* max. rate */
